*FILE PREPARATION SECTION.  CAN BE SKIPPED IF THE .SAV FILE HAS ALREADY BEEN FINALIZED.
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: Food Purchases
*Purpose: To gather the variables from the raw data required for calculating food purchases.
*Data: Part B : Section 9: Frequently Purchased items


*--------------------------------------------------------------------------------------------------------------------------.
*BELOW THIS LINE FOR COMPUTATION OF AGGREGATES.

* Step 1: Filtering out items not consumed.
GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9B.sav'.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF(s9bq1=1 and s9bq0 <>998).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_B_Filtered.sav'.


*Step 2: Computing the total value consumption
*In this case, the recall periods were supposed to be based on a household diary with the calculations done by the enumerator.  However,
*it would have been preferable to simply key in the diary and annulaize these based on onbe month consumption.
*Also the units of consumption were kept in the household diary and were not keyed in.

*This method will accept the case if they claim quarterly over annual declaration.

IF (s9bq3>0) Ann_Prch = s9bq3 .
VARIABLE LABELS Ann_Prch 'Annual Purchases of item' .
EXECUTE .

IF (s9bq6>0) Ann_Prch = s9bq6*4 .
VARIABLE LABELS Ann_Prch 'Annual Purchases of item' .
EXECUTE .


*Step 3: Sort cases by key and merge data from HHSize file.

SORT CASES BY
  hhid (A) .


MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household Survey_2003\AggData\HHSize.sav'
 /BY hhid.
EXECUTE.




*Step 4. Calculate per adult equivalent consumption to test for outliers.


IF (ctry_adq>=1) Aecon = ann_prch/ctry_adq .
EXECUTE .
IF (ctry_adq<1) Aecon = ann_prch*ctry_adq .
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_B_Filtered.sav'.

*Aggregating: Breads, rice in all forms, maize, wheat, cereal and cereal cassava, plantain, and potato, couscous, etc.  

IF (s9bq0>=100 and s9bq0<200) FTYPE = 1 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: All meats and poultry, including game meats and their by products, excluding fats.

IF (s9bq0>=200 and s9bq0<300) FTYPE = 2 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Fish, shell fish, land snails, land crabs, and frogs.

IF (s9bq0>=300 and s9bq0<400) FTYPE = 3 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Milk, cheese, other dairy products and eggs.

IF (s9bq0>=400 and s9bq0<500) FTYPE = 4 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .


*Aggregating: Vegetable oil, animal fats and oil-rich nuts.

IF (s9bq0>=500 and s9bq0<600) FTYPE = 5 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Fruits.

IF (s9bq0>=600 and s9bq0<700) FTYPE = 6 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Vegetables.

IF (s9bq0>=700 and s9bq0<800) FTYPE = 7 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Sweets, desserts, cookies, candies, jams, honey.

IF (s9bq0>=800 and s9bq0<900) FTYPE = 8 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: All beverages, including coffee, tea, cocoa, mineral water, soft drinks, and juices.

IF (s9bq0>=900 and s9bq0<950) FTYPE = 9 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Food consumed in restaurants and canteens.

IF s9bq0=99 FTYPE = 10 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Items not mentioned elsewhere.

IF (s9bq0>=0 and s9bq0<50) FTYPE = 11 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_B_Agg.sav'
  /BREAK=hhid ftype
  /ann_pr_1 'Annual Purchases' = SUM(ann_prch).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_B_Agg.sav'.

SORT CASES BY hhid ftype .
FILTER OFF.
USE ALL.
SELECT IF(ftype>0).
EXECUTE .

CASESTOVARS
 /ID = hhid
 /INDEX = ftype
 /GROUPBY = VARIABLE .

VARIABLE LABELS V1 'FDBRDBY' .
VARIABLE LABELS V2 'FDMEATBY' .
VARIABLE LABELS V3 'FDFISHBY' .
VARIABLE LABELS V4 'FDDAIRBY' .
VARIABLE LABELS V5 'FDFATSBY' .
VARIABLE LABELS V6 'FDFRUTBY' .
VARIABLE LABELS V7 'FDVEGBY' .
VARIABLE LABELS V8 'FDSWTBY	' .
VARIABLE LABELS V9 'FDBEVBY' .
VARIABLE LABELS V10 'FDRESTBY' .
VARIABLE LABELS V11 'FDOTHBY' .

IF (sysmis(v1)) v1 = 0 .
EXECUTE .

IF (sysmis(v2)) v2 = 0 .
EXECUTE .

IF (sysmis(v3)) v3 = 0 .
EXECUTE .

IF (sysmis(v4)) v4 = 0 .
EXECUTE .

IF (sysmis(v5)) v5 = 0 .
EXECUTE .

IF (sysmis(v6)) v6 = 0 .
EXECUTE .

IF (sysmis(v7)) v7 = 0 .
EXECUTE .

IF (sysmis(v8)) v8 = 0 .
EXECUTE .

IF (sysmis(v9)) v9 = 0 .
EXECUTE .

IF (sysmis(v10)) v10 = 0 .
EXECUTE .

IF (sysmis(v11)) v11 = 0 .
EXECUTE .

COMPUTE FDTOTBY = v1 +  v2 +  v3 + v4 + v5 + v6 + v7 + v8 + v9 + v10 + v11 .
VARIABLE LABELS FDTOTBY 'Annual total monetary value of purchased foods, '+
 ' in current local prices' .
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXFDBUY.sav'.
