*FILE PREPARATION SECTION.  CAN BE SKIPPED IF THE .SAV FILE HAS ALREADY BEEN FINALIZED.
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: consumpton of own produce
*Purpose: To gather the variables from the raw data required for calculating food purchasesclean them and produce files.
*Data: Section 8: Agriculture Part H: Consumption of own produce.

*open the SPSS file that contains all rows of data for Section 8H.


*--------------------------------------------------------------------------------------------------------------------------.
*PREPARING VARIABLES FOR AGREGATION (FIRST PASS).

* Step 1: Filtering out items not consumed.
GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec8H.sav'.

FILTER OFF.
USE ALL.
SELECT IF(s8hq1=1).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec8H_Filtered.sav'.

*Step 2a: Replacing blanks with 0.  This will be better done through the data edit program.  Since this is filtered based on response to s8hq1.

IF (sysmis(s8hq3)) s8hq3 = 0 .
EXECUTE .
IF (sysmis(s8hq4)) s8hq4 = 0 .
EXECUTE .
IF (sysmis(s8hq5)) s8hq5 = 0 .
EXECUTE .
IF (sysmis(s8hq6)) s8hq6 = 0 .
EXECUTE .
IF (sysmis(s8hq7)) s8hq7 = 0 .
EXECUTE .
IF (sysmis(s8hq8)) s8hq8 = 0 .
EXECUTE .


*Step 2b: Computing the total unit consumption


COMPUTE Unit_Con = s8hq3 + s8hq4 + s8hq5 +s8hq6 +s8hq7 +s8hq8 .
VARIABLE LABELS Unit_Con 'Units Consumed' .
EXECUTE .


*Step 2c(a): Per cycle consumption.


IF (unit_con>0) cyc_con = unit_con*s8hq10 .
EXECUTE .


*Step 2c(b): Annualize and value the output according to the 30 day cycle

IF (unit_con>0) AnCon =  unit_con*(365/30)*s8hq10 .
EXECUTE .



*Step 3: Sort cases by key and merge data from HHSize file.


SORT CASES BY
  hhid (A) .

MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household Survey_2003\AggData\HHSize.sav'
 /BY hhid.
EXECUTE.



*Step 4A. Calculate per adult equivalent soncumption to test for outliers.
*sort Data by product and unit consumed.


SORT CASES BY
  s8hq0 (A) s8hq9 (A) .

*saving file to verify unit consistency

IF (ctry_adq>=1) Aecon = ancon/ctry_adq .
EXECUTE .
IF (ctry_adq<1) Aecon = ancon*ctry_adq .
EXECUTE .

IF (ctry_adq>=1) AECyc = Cyc_con/ctry_adq .
EXECUTE .
IF (ctry_adq<1) AECyc = Cyc_con*ctry_adq .
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec8H_Filtered.sav'.

*Aggregating: Breads, rice in all forms, maize, wheat, cereal and cereal cassava, plantain, and potato, couscous, etc.  

IF (s8hq0>=100 and s8hq0<200) FTYPE = 1 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: All meats and poultry, including game meats and their by products, excluding fats.

IF (s8hq0>=200 and s8hq0<300) FTYPE = 2 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Fish, shell fish, land snails, land crabs, and frogs.

IF (s8hq0>=300 and s8hq0<400) FTYPE = 3 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Milk, cheese, other dairy products and eggs.

IF (s8hq0>=400 and s8hq0<500) FTYPE = 4 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .


*Aggregating: Vegetable oil, animal fats and oil-rich nuts.

IF (s8hq0>=500 and s8hq0<600) FTYPE = 5 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Fruits.

IF (s8hq0>=600 and s8hq0<700) FTYPE = 6 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Vegetables.

IF (s8hq0>=700 and s8hq0<800) FTYPE = 7 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Sweets, desserts, cookies, candies, jams, honey.

IF (s8hq0>=800 and s8hq0<900) FTYPE = 8 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: All beverages, including coffee, tea, cocoa, mineral water, soft drinks, and juices.

IF (s8hq0>=900 and s8hq0<950) FTYPE = 9 .
VARIABLE LABELS FTYPE 'Food Aggregate Type (World Bank)' .
EXECUTE .


AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec8_H_Agg.sav'
  /BREAK=hhid ftype
  /ann_op 'Annual Purchases' = SUM(ancon).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec8_H_Agg.sav'.

SORT CASES BY hhid ftype .
FILTER OFF.
USE ALL.
SELECT IF(ftype>0).
EXECUTE .

CASESTOVARS
 /ID = hhid
 /INDEX = ftype
 /GROUPBY = VARIABLE .

VARIABLE LABELS V1 'FDBRDPR' .
VARIABLE LABELS V2 'FDMEATPR' .
VARIABLE LABELS V3 'FDFISHPR' .
VARIABLE LABELS V4 'FDDAIRPR' .
VARIABLE LABELS V5 'FDFATSPR' .
VARIABLE LABELS V6 'FDFRUTPR' .
VARIABLE LABELS V7 'FDVEGPR' .
VARIABLE LABELS V8 'FDBEVPR' .



IF (sysmis(v1)) v1 = 0 .
EXECUTE .

IF (sysmis(v2)) v2 = 0 .
EXECUTE .

IF (sysmis(v3)) v3 = 0 .
EXECUTE .

IF (sysmis(v4)) v4 = 0 .
EXECUTE .

IF (sysmis(v5)) v5 = 0 .
EXECUTE .

IF (sysmis(v6)) v6 = 0 .
EXECUTE .

IF (sysmis(v7)) v7 = 0 .
EXECUTE .

IF (sysmis(v8)) v8 = 0 .
EXECUTE .



COMPUTE FDTOTPR = v1 +  v2 +  v3 + v4 + v5 + v6 + v7 + v8   .
VARIABLE LABELS FDTOTPR 'Total annual expenditure of own produce'
EXECUTE .

FILTER OFF.
USE ALL.
SELECT IF(fdtotpr>0).
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXFDPRD.sav'.
