 
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: Health expenditures.
*Purpose: To gather the variables from the raw data required for calculating the household reference file.
*Data: Part A : Section 3a,b,c,d Health Roster.
*Procedure:

*open the SPSS file that contains the data for primary variables to compute the household composition.
*see SPSS syntax Part_A.sps for details on the creation of this file.



*--------------------------------------------------------------------------------------------------------------------------.
*BELOW THIS LINE FOR COMPUTATION OF HOUSEHOLD COMPOSITION AND REFERENCE FILE.


*Step 1:  Retrieve file from health section 3a.  

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\Hlth_Sec3A.sav'.


*Filter out pre and post natal care and vaccination since we are using data from other sections.


FILTER OFF.
USE ALL.
SELECT IF(s3aq6<4).
EXECUTE .

*Impute by sorting and replacing with median.  This should be taken care of by a CSPro program.


IF (s3aq10>=150000) s3aq10 = 1000 .
EXECUTE .


IF (s3aq11>=88000) s3aq11 = 0 .
EXECUTE .



IF (s3aq17>=550000) s3aq17 = 5000.
EXECUTE .


IF (s3aq19>=450000) s3aq19 = 3000.
EXECUTE .


IF (s3aq19=10) s3aq19 = 100.
EXECUTE .




SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec3A_filtered.sav'.

*Step 2: Annualize and aggregate household expenditure on health and save out file.

*annualizing consultations (excluding vaccines, post and prenatal).

IF (s3aq7a>0 and sysmis(s3aq7b) and sysmis(s3aq7c)) XCon = 1 .
VARIABLE LABELS XCon 'Time Consulted' .
EXECUTE .
IF (s3aq7a>0 and s3aq7b>0 and sysmis(s3aq7c)) XCon = 2 .
VARIABLE LABELS XCon 'Time Consulted' .
EXECUTE .
IF (s3aq7a>0 and s3aq7b>0 and s3aq7c>0) XCon = 3 .
VARIABLE LABELS XCon 'Time Consulted' .
EXECUTE .


COMPUTE hlcon1 = s3aq10*26*XCon .
EXECUTE .

COMPUTE hltr1 = s3aq11*26*XCon .
EXECUTE .

COMPUTE hlhos1 = s3aq17*26 .
EXECUTE .

COMPUTE hlmed1 = s3aq19*26 .
EXECUTE .

COMPUTE hlpok1 = s3aq20*26 .
EXECUTE .


AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Hlth_Sec_Agg.sav'
  /BREAK=hhid
  /hlcon 'Consultations' = SUM(hlcon1) /hltrsp 'Transport' = SUM(hltr1)
  /hlhospt 'Hospitalization' = SUM(hlhos1) /hlmedc 'Medication' =
  SUM(hlmed1) /paid 'Out_of_pocket' = SUM(hlpok1).

*Step 2: Aggregate expenditures on preventive health---------------------------------------------------------.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\Hlth_Sec3B.sav'.

FILTER OFF.
USE ALL.
SELECT IF(s3bq2=1).
EXECUTE .



*Change no answers to 0 to sum across.

IF (s3bq3d=2) s3bq3d = 0 .
EXECUTE .

IF (s3bq3p=2) s3bq3p = 0 .
EXECUTE .

IF (s3bq3m=2) s3bq3m = 0 .
EXECUTE .

IF (s3bq3b=2) s3bq3b = 0 .
EXECUTE .

*deal with MISSING values.

if sysmis(s3bq3d) s3bq3d=0 .
if sysmis(s3bq3p) s3bq3p=0 .
if sysmis(s3bq3m) s3bq3m=0 .
if sysmis(s3bq3b) s3bq3b=0 .
EXECUTE .

*Calculate all vaccines administered.

COMPUTE TotVax = s3bq3d+s3bq3p+s3bq3m+s3bq3b .
EXECUTE .

COMPUTE prevex = totvax*s3bq7 .
EXECUTE .


*impute these values.  Should be done by CSPro.



IF (prevex=0 or sysmis(prevex)) prevex = 500 .
EXECUTE .


IF (prevex>10000) prevex = 500 .
EXECUTE .




AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3B_Agg.sav'
  /BREAK=hhid
  /HLPREV 'Aggregate preventive' = SUM(prevex).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

EXECUTE.
SORT CASES BY
  hhid (A) .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3B_Agg.sav'.
EXECUTE.

SORT CASES BY
  hhid (A) .
SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3B_Agg.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

MATCH FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3B_Agg.sav'
 /BY hhid.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

*Step 3: Aggregate expenditures on postnatal care health---------------------------------------------------------.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\Hlth_Sec3C.sav'.
USE ALL.

*Select only those wo have paid.

FILTER OFF.
USE ALL.
SELECT IF(s3cq4=1).
EXECUTE .

*Annualize expenditures.
COMPUTE TotPN = s3cq3*s3cq5 .
VARIABLE LABELS TotPN 'Total Postnatal' .
EXECUTE .
USE ALL.

*Filtering vaccinations since they are covered in the preventive section

FILTER OFF.
USE ALL.
SELECT IF(s3cq11<>1).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec3C_Filtered.sav'.

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3C_Agg.sav'
  /BREAK=hhid
  /HLPOST 'postnatal' = SUM(totpn).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3C_Agg.sav'.

SORT CASES BY
  hhid (A) .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3C_Agg.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

SORT CASES BY
  hhid (A) .

MATCH FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3C_Agg.sav'
 /BY hhid.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.


*Step 3: Aggregate expenditures on prenatal care health---------------------------------------------------------.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\Hlth_Sec3D.sav'.

*select only cases where care was administered.

FILTER OFF.
USE ALL.
SELECT IF(s3dq15=1).
EXECUTE .

*computing totals
*imputing number of visits and amount paid by looking at median.  This should be added to a CSPro program.

IF (s3dq18>=20) s3dq18 = 5 .
EXECUTE .
IF (s3dq19=2) s3dq19 = 200 .
EXECUTE .
IF (s3dq19=4) s3dq19 = 400 .
EXECUTE .
IF (s3dq19>=50000) s3dq19 = 3000 .
EXECUTE .




COMPUTE pretot = s3dq18*s3dq19 .
VARIABLE LABELS pretot 'Prenatal totals' .
EXECUTE .


SORT CASES BY
  hhid (A) .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec3D_filtered.sav'.


AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3D_Agg.sav'
  /BREAK=hhid
  /PRENAT 'Prenatal care' = SUM(pretot).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

SORT CASES BY
  hhid (A) .

MATCH FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_3D_Agg.sav'
 /BY hhid.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Hlth_Sec_Agg.sav'.

*replace sysmis with 0 to sum totals



IF (sysmis(hlcon)) hlcon = 0 .
EXECUTE .

IF (sysmis(hltrsp)) hltrsp = 0 .
EXECUTE .

IF (sysmis(hlhospt)) hlhospt = 0 .
EXECUTE .

IF (sysmis(hlmedc)) hlmedc = 0 .
EXECUTE .

IF (sysmis(paid)) paid = 0 .
EXECUTE .

IF (sysmis(hlprev)) hlprev = 0 .
EXECUTE .

IF (sysmis(hlpost)) hlpost = 0 .
EXECUTE .

IF (sysmis(prenat)) prenat = 0 .
EXECUTE .

*Computing total consultations.
COMPUTE hlcnslt = hlcon+hlprev+hlpost+prenat .
VARIABLE LABELS hlcnslt 'Total Consultations' .
EXECUTE .

*computing total healtcare expenditures.
COMPUTE hltexp = hlcnslt+hltrsp+hlhospt+hlmedc .
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXHLTH.sav'.

