*FILE PREPARATION SECTION.  CAN BE SKIPPED IF THE .SAV FILE HAS ALREADY BEEN FINALIZED.
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: Non-food frequently purchased items
*Purpose: To gather the variables from the raw data required for calculating food purchases.
*Data: Part A2 : Section 9: Frequently Purchased items (NON FOOD)

*open the SPSS file that contains all rows of data for Section 9A2.


   *--------------------------------------------------------------------------------------------------------------------------.
*BELOW THIS LINE FOR COMPUTATION OF AGGREGATES.

* Step 1: Filtering out items not consumed or redundant.
GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9A2.sav'.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF(s9A2q1=1).
EXECUTE .

*Eliminating redundant areas.
SELECT IF(s9a2q0<>307 and s9a2q0<>308 and s9a2q0<>309 and s9a2q0<>310 and s9a2q0<>311 and s9a2q0<>312 and s9a2q0<>327 and s9a2q0<>328 and
  s9a2q0<>329 and s9a2q0<>330 and s9a2q0<>331 and s9a2q0<>332 and s9a2q0<>333 and s9a2q0<>334 and s9a2q0<>335 and s9a2q0<>336 
 and s9a2q0<>350 and s9a2q0<>351 and s9a2q0<>352 and s9a2q0<>358 and s9a2q0<>359 and s9a2q0<>361).
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.

*Save out medicines and compare with health expenditures

SELECT IF(s9a2q0=303 or s9a2q0=304 or s9a2q0=305 or s9a2q0=306).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Medicines.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.

SELECT IF(s9a2q0<>303 and s9a2q0<>304 and s9a2q0<>305 and s9a2q0<>306).
EXECUTE .


*Step 2: Computing the total value consumption
*In this case, the recall periods were supposed to be based on a household diary with the calculations done by the enumerator.  However,
*it would have been preferable to simply key in the diary and annulaize these based on onbe month consumption.
*Also the units of consumption were kept in the household diary and were not keyed in.

IF (s9A2q3>0) Ann_NF = s9A2q3 .
VARIABLE LABELS Ann_NF 'Annual Purchases of item' .
EXECUTE .

IF (s9A2q6>0) Ann_NF = s9A2q6*4 .
VARIABLE LABELS Ann_NF 'Annual Purchases of item' .
EXECUTE .


*Step 3: Sort cases by key and merge data from HHSize file and other indicators to check ratios.

SORT CASES BY
  hhid (A) .
EXECUTE.


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.

*Computing aggregate

GET FILE='C:\Sierra Leone_Household Survey_2003\Interfiles\Sec9_B_Filtered.sav'.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF(s9bq0=999).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_B_Tobacco.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.

ADD FILES /FILE=*
 /RENAME (s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6 = d0 d1 d2 d3 d4 d5)
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_B_Tobacco.sav'
 /RENAME (aecon ctry_adq fao_adq hhsize s9bq1 s9bq2 s9bq3 s9bq4 s9bq5 s9bq6
  s9brc = d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16) s9bq0=s9a2q0
  ann_prch=ann_nf
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16.
EXECUTE.



SORT CASES BY
  hhid (A) s9a2q0 (A) .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.


* Step 1: Filtering out items not consumed.  This file although it is not frequent is integrated into frequent.  There is a great deal of redundancy between the items in
the questionnaires (between freqent and non frequent).

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9A1.sav'.
EXECUTE.

FILTER OFF.
USE ALL.
SELECT IF(s9A1q1=1).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A1_Filtered.sav'.


*Step 2: Computing the total value consumption
*In this case, the recall periods were supposed to be based on a household diary with the calculations done by the enumerator.  However,
*it would have been preferable to simply key in the diary and annulaize these based on onbe month consumption.
*Also the units of consumption were kept in the household diary and were not keyed in.

IF (s9A1q2<12) Ann_Prch = s9A1q3 .
VARIABLE LABELS Ann_Prch 'Annual Purchases of item' .
EXECUTE .

IF (s9A1q2>=12) Ann_Prch = s9A1q4*4 .
VARIABLE LABELS Ann_Prch 'Annual Purchases of item' .
EXECUTE .


*Step 3: Sort cases by key and merge data from HHSize file.

SORT CASES BY
  hhid (A) .
EXECUTE.


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A1_Filtered.sav'.

*There is a great deal of redundancy in the items.  Many of these items were included in the frequently purchased file as the World Bank aggregate was designed in this fashion.
*For more infomation please refer to the process manual.




GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A1_Filtered.sav'.

*Despite the WB aggregate has clothes as frequent and they were surveyed as infrequent, the clothes will be aggregated as frequent.

USE ALL.
SELECT IF(s9a1q0>=201 and s9a1q0<=219 or s9a1q0>=222 and s9a1q0<=223).
EXECUTE .

FILTER OFF.
SORT CASES BY
  hhid (A) s9a1q0 (A) .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A1_Clothes.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.

USE ALL.
ADD FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A1_Clothes.sav'
 /RENAME (s9a1q1 s9a1q2 s9a1q3 s9a1q4 = d0 d1 d2 d3) s9a1q0=s9a2q0
  ann_prch=ann_nf
 /DROP= d0 d1 d2 d3.
EXECUTE.


SELECT IF(ann_nf>0).
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.


*This section is for working on Section 7A in order to extract information on rent and utilities.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\House_Sec7.sav'.

*Put things in their appropriate columns.  Will do a batch edit in CSPro.

IF (sysmis(s7bq11) and s7bq12a>0) s7bq11 = 2 .
EXECUTE .

IF ((s7bq11=1 or s7bq11=3 or s7bq11=4) and s7bq12a>0) s7bq12b = s7bq12a .
EXECUTE .

IF (s7bq11<>2) s7bq12a = 0 .
EXECUTE .

IF (s7bq11=2 and s7bq12b>0) s7bq12a = s7bq12b .
EXECUTE .

IF (s7bq11=2) s7bq12b = 0 .
EXECUTE .


*Calculating rent

IF (s7bq11<>2 ) an_rent = 12*s7bq12b .
EXECUTE .

IF (s7bq11=2) an_rent = 12*s7bq12a .
EXECUTE .


*computing utilites: WATER
IF (s7dq24t=1) WATER = s7dq24a*365. 
EXECUTE .
IF (s7dq24t=2) WATER = s7dq24a*52 .
EXECUTE .
IF (s7dq24t=3) WATER = s7dq24a*12 .
EXECUTE .
IF (s7dq24t=4) WATER = s7dq24a*4 .
EXECUTE .
IF (s7dq24t=5) WATER = s7dq24a*2 .
EXECUTE .
IF (s7dq24t=6) WATER = s7dq24a*1.
EXECUTE .
*computing neighbors standpipe.  There is a double count between q25 and q24.  If q25 then opt for this value.

IF (s7dq25>0) WATER = s7dq25*26. 
EXECUTE .


*computing utilites: ELECTRICITY
IF (s7dq29t=1) ELEC = s7dq29*365. 
EXECUTE .
IF (s7dq29t=2) ELEC = s7dq29*52 .
EXECUTE .
IF (s7dq29t=3) ELEC = s7dq29*12 .
EXECUTE .
IF (s7dq29t=4) ELEC = s7dq29*4 .
EXECUTE .
IF (s7dq29t=5) ELEC = s7dq29*2 .
EXECUTE .
IF (s7dq29t=6) ELEC = s7dq29*1.
EXECUTE .


*computing utilites: RUBBISH
IF (s7dq32t=1) RUBB = s7dq32*365. 
EXECUTE .
IF (s7dq32t=2) RUBB = s7dq32*52 .
EXECUTE .
IF (s7dq32t=3) RUBB = s7dq32*12 .
EXECUTE .
IF (s7dq32t=4) RUBB = s7dq32*4 .
EXECUTE .
IF (s7dq32t=5) RUBB = s7dq32*2 .
EXECUTE .
IF (s7dq32t=6) RUBB = s7dq32*1.
EXECUTE .

IF (sysmis(water)) water = 0 .
EXECUTE .

IF (sysmis(elec)) elec = 0 .
EXECUTE .

IF (sysmis(rubb)) rubb = 0 .
EXECUTE .


COMPUTE TOTUT = water+elec+rubb .
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\House_Sec7_Utilities_Rent.sav'.

FILTER OFF.
USE ALL.
SELECT IF(totut>0).
EXECUTE .

SORT CASES BY
  hhid (A) .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\House_Sec7_Utilities.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\House_Sec7_Utilities_Rent.sav'.

SORT CASES BY
  hhid (A) .

RECODE
  s7eq34
  (1=1)  (2=2)  (3=3)  (4 thru 5=4)  INTO  WALL .
VARIABLE LABELS WALL 'Wall'.
EXECUTE .

RECODE
  s7eq35
  (1=1)  (2=2)  (SYSMIS=1)  (3 thru 4=3)  INTO  FLOOR .
VARIABLE LABELS Roof 'Roof'.
EXECUTE .

RECODE
  s7eq36
  (1=1)  (2=2)  (SYSMIS=1)  (4=1)  (2 thru 3=3)  (5 thru 6=4)  INTO  ROOF .
VARIABLE LABELS roof 'Roof'.
EXECUTE .


DO IF (s7eq34=6) .
RECODE
  s7eq35
  (1=1)  (2=2)  (3 thru 4=3)  INTO  WALL .
END IF .
EXECUTE .

DO IF (s7eq35=5) .
RECODE
  s7eq34
  (1=1)  (2=2)  (5=3)  (2 thru 4=2)  INTO  FLOOR .
END IF .
EXECUTE .

DO IF (s7eq36=7) .
RECODE
  s7eq35
  (1=1)  (3=3)  (2 thru 3=2)  INTO  ROOF .
END IF .
EXECUTE .


IF (sysmis(wall)) wall = 1 .
EXECUTE .

IF (sysmis(floor)) floor = 1 .
EXECUTE .


IF (sysmis(roof)) roof = 1 .
EXECUTE .




COMPUTE QIndex = wall+roof+floor .
EXECUTE .

*These regressions were run but did nit have a grat effect on the outcome when compared with the CSPro dynamic imoutations.
*Form regression on actual rent paid.
*Models were done on actual rent vs. total even though self imputed were not coherent.  Regression was selected using all rent against the quality index.


*Model using all rent declared.
*COMPUTE rntimp = -86418+48230*qindex .
*EXECUTE .

*Model using actual rent.
*COMPUTE rntimp=-140962+47286*qindex.


*Calculate rent

IF (s7bq11=1) RntSta = 1 .
VARIABLE LABELS RntSta 'Rent Status' .
EXECUTE .

IF (s7bq11=2) RntSta = 2 .
VARIABLE LABELS RntSta 'Rent Status' .
EXECUTE .

IF (s7bq11>2 and s7bq11<=5) RntSta = 3 .
VARIABLE LABELS RntSta 'Rent Status' .
EXECUTE .

IF (s7bq11>=6) RntSta = 4 .
VARIABLE LABELS RntSta 'Rent Status' .
EXECUTE .

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent.sav'
  /BREAK=hhid rntsta
  /Rent 'Rent self declared or actual' = MEAN(an_rent).


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\House_Sec7_Utilities_Rent.sav'.



GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Filtered.sav'.

SORT CASES BY
  hhid (D) .

ADD FILES /FILE=*
 /FILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\House_Sec7_Utilities.sav'
 /RENAME (an_rent elec rubb s7aq1 s7aq2 s7aq3 s7aq4m s7aq4y s7aq5 s7aq6
  s7bq10 s7bq11 s7bq12 s7bq12a s7bq12b s7bq7 s7bq8 s7bq9 s7cq13 s7cq14t
  s7cq14v s7cq15 s7cq16 s7cq17 s7cq18 s7cq19t s7cq19v s7cq20 s7dq21 s7dq22c
  s7dq22d s7dq23 s7dq24a s7dq24t s7dq25 s7dq26 s7dq27 s7dq28 s7dq29 s7dq29t
  s7dq30 s7dq31 s7dq32 s7dq32t s7dq33 s7eq34 s7eq35 s7eq36 s7eq37 s7fq38
  s7fq39a s7fq39b s7fq39c s7fq40 s7fq41a s7fq41b s7fq41c s7fq42 s7fq43 s7fq44
  s7fq45 s7fq46 s7fq47 s7fq48 s7fq49 s7fq50 s7fq51 s7fq52 water = d0 d1 d2 d3
  d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23
  d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42
  d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61
  d62 d63 d64 d65 d66 d67 d68) totut=ann_nf
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19
  d20 d21 d22 d23 d24 d25 d26 d27 d28
 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42 d43 d44 d45 d46 d47
  d48 d49 d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61 d62 d63 d64 d65 d66
  d67 d68.
EXECUTE.



*Label the imported utilities with code 500 for aggregating.

IF (sysmis(s9a2q0)) s9a2q0 = 500 .
EXECUTE .


*Aggregating: tobacco and narcotics (Alcoholic beverages included in food as they provde a caloric value).

IF (s9a2q0=999) NFTYPE = 1 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Expenditures paid for utilities, including water, electricity, fuel, gas, etc.

IF (s9a2q0>=278 and s9a2q0<=282 or s9a2q0=500) NFTYPE = 2 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Clothing, shoes, fabrics, sheets, etc.

IF (s9a2q0>=201 and s9a2q0<=219 or s9a2q0=222) NFTYPE = 3 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Furnishing and routine household maintenance, tools and equipment for house and garden, and goods and services for routine household maintenance.

IF (s9a2q0>=283 and s9a2q0<=302) NFTYPE = 4 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Transportation (need to chec on the ncluson of care etc.)

IF (s9a2q0>=313 and s9a2q0<=324) NFTYPE = 5 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating:Postal services; telephone and telefax services and internet services.

IF (s9a2q0>=325 and s9a2q0<=326) NFTYPE = 6 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Recreational, cultural and sport services, newspapers, magazines, books and stationery (excluding books for schooling). 

IF (s9a2q0>=337 and s9a2q0<=346 or s9a2q0=363 or s9a2q0=359 ) NFTYPE = 7 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .

*Aggregating: Other frequent non-food expenditures not mentioned above

IF (s9a2q0>=347 and s9a2q0<=349 or s9a2q0=357 or s9a2q0=360 or s9a2q0=362 or s9a2q0=364 or s9a2q0=365) NFTYPE = 8 .
VARIABLE LABELS NFTYPE 'Non Food Aggregate Type (World Bank)' .
EXECUTE .


*Filters out any miscoded items. 
FILTER OFF.
USE ALL.
SELECT IF(nftype>0).
EXECUTE .

SORT CASES BY
  hhid (A) .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Freq_NF_Details.sav'.

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_agg.sav'
  /BREAK=hhid nftype
  /ann_nf_1 = SUM(ann_nf).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec9_A2_Agg.sav'.

USE ALL.
SELECT IF(nftype>0).
EXECUTE .

SORT CASES BY hhid nftype .
CASESTOVARS
 /ID = hhid
 /INDEX = nftype
 /GROUPBY = VARIABLE .

VARIABLE LABELS V1 'NFDTBAC' .
VARIABLE LABELS V2 'NFDUTIL' .
VARIABLE LABELS V3 'NFDFCLOTH' .
VARIABLE LABELS V4 'NFDFMTN' .
VARIABLE LABELS V5 'NFDTRANS' .
VARIABLE LABELS V6 'NFDCOMM' .
VARIABLE LABELS V7 'NFDRECRE' .
VARIABLE LABELS V8 'NFDFQOTH' .

IF (sysmis(v1)) v1 = 0 .
EXECUTE .

IF (sysmis(v2)) v2 = 0 .
EXECUTE .

IF (sysmis(v3)) v3 = 0 .
EXECUTE .

IF (sysmis(v4)) v4 = 0 .
EXECUTE .

IF (sysmis(v5)) v5 = 0 .
EXECUTE .

IF (sysmis(v6)) v6 = 0 .
EXECUTE .

IF (sysmis(v7)) v7 = 0 .
EXECUTE .

IF (sysmis(v8)) v8 = 0 .
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

   *--------------------------------------------------------------------------------------------------------------------------.

*Adding Rent

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent.sav'.

*Select all owner declared values.

FILTER OFF.
USE ALL.
SELECT IF(rntsta=1).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Own.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent.sav'.

*Select all owner declared values.

FILTER OFF.
USE ALL.
SELECT IF(rntsta=2 or rntsta=3).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Actual.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\House_Sec7_Utilities_Rent.sav'.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Imp.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Sec7_Rent_Actual.sav'
 /RENAME (rntsta = d0) rent=RNTACTL
 /BY hhid
 /DROP= d0.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Own.sav'.

SORT CASES BY
  hhid (A) .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Own.sav'.


GET FILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

SORT CASES BY
  hhid (A) .


MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Own.sav'
 /RENAME (rntsta = d0) rent=RNTIF
 /BY hhid
 /DROP= d0.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.


GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Imp.sav'.

SORT CASES BY
  hhid (A) .




SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec7_Rent_Imp.sav'.


GET FILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

SORT CASES BY
  hhid (A) .



MATCH FILES /TABLE=*
 /FILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Sec7_Rent_Imp.sav'
 /RENAME (an_rent chiefdom district ea elec floor hhnum qindex rectype region
  rntsta roof rubb s7aq1 s7aq2 s7aq3 s7aq4m s7aq4y s7aq5 s7aq6 s7bq10 s7bq11
  s7bq12 s7bq12a s7bq12b s7bq7 s7bq8 s7bq9 s7cq13 s7cq14t s7cq14v s7cq15
  s7cq16 s7cq17 s7cq18 s7cq19t s7cq19v s7cq20 s7dq21 s7dq22c s7dq22d s7dq23
  s7dq24a s7dq24t s7dq25 s7dq26 s7dq27 s7dq28 s7dq29 s7dq29t s7dq30 s7dq31
  s7dq32 s7dq32t s7dq33 s7eq34 s7eq35 s7eq36 s7eq37 s7fq38 s7fq39a s7fq39b
  s7fq39c s7fq40 s7fq41a s7fq41b s7fq41c s7fq42 s7fq43 s7fq44 s7fq45 s7fq46
  s7fq47 s7fq48 s7fq49 s7fq50 s7fq51 s7fq52 totut urbrur wall water = d0 d1 d2
  d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23
  d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38 d39 d40 d41 d42
  d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 d57 d58 d59 d60 d61
  d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 d75 d76 d77
 d78 d79 d80 d81)
 /BY hhid
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19
  d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34 d35 d36 d37 d38
  d39 d40 d41 d42 d43 d44 d45 d46 d47 d48 d49 d50 d51 d52 d53 d54 d55 d56 d57
  d58 d59 d60 d61 d62 d63 d64 d65 d66 d67 d68 d69 d70 d71 d72 d73 d74 d75 d76
  d77 d78 d79 d80 d81.
EXECUTE.



SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

*Convert missing to 0 to add

IF (sysmis(rntactl)) rntactl = 0 .
EXECUTE .

IF (sysmis(rntif)) rntif = 0 .
EXECUTE .


*For the purposes of the aggregate, imputed "0" values with median rent of 96,000.  WIll have to check on hotdeck to see why there are "0".


* computing rent of hh.
COMPUTE rnthh = rntactl+rntif .
EXECUTE .


IF (sysmis(rnthh)) rnthh = 96000 .
EXECUTE .
IF (rnthh=0) rnthh = 96000 .
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

*Add non-farm own consumption.
*The questionnaire is unclear as to which of the categores Q5 or Q8 or Q10 is correct nor was the  survey staff certan the reasonng behnd the queston repetton.
*The first one is take an annualized.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10D.sav'.


FILTER OFF.
USE ALL.
SELECT IF(s10dq4=1).
EXECUTE .
FILTER OFF.
USE ALL.
SELECT IF(s10dq5>0).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Enterprise_Sec10D_Filtered.sav'.

*annualize.
COMPUTE NFDTOT = s10dq5*26 .
VARIABLE LABELS NFDTOT 'NFDTOTPR' .
EXECUTE .

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Enterprise_Sec10D_Agg.sav'
  /BREAK=hhid
  /NFDTOTPR 'Total monetary value of self-produced non-foods' = SUM(nfdtot).

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Enterprise_Sec10D_Filtered.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\Interfiles\Enterprise_Sec10D_Agg.sav'.

SORT CASES BY
  hhid (A) .

GET FILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

SORT CASES BY
  hhid (A) .

MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Enterprise_Sec10D_Agg.sav'
 /BY hhid.
EXECUTE.

IF (sysmis(nfdtotpr)) nfdtotpr = 0 .
EXECUTE .
FILTER OFF.


COMPUTE NFDFQTOT = v1 +  v2 +  v3 + v4 + v5 + v6 + v7 + v8.

VARIABLE LABELS NFDFQTOT  'Annual total frequent non-food expenditures, in current local prices, excluding rent ' .
EXECUTE .



SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDFQ.sav'.

