*FILE PREPARATION SECTION.  CAN BE SKIPPED IF THE .SAV FILE HAS ALREADY BEEN FINALIZED.
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: Non-food NOT frequently purchased items
*Purpose: To gather the variables from the raw data required for calculating food purchases.
*Data: Part A1 : Section 9A1: Not Frequently Purchased items (NON FOOD)

*open the SPSS file that contains all rows of data for Section 9A1.
*--------------------------------------------------------------------------------------------------------------------------.
*BELOW THIS LINE FOR COMPUTATION OF AGGREGATES.
*Calulating durable items using section 12B.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\Credits_Sec12B.sav'.

*Only selecting thos items declared.
FILTER OFF.
USE ALL.
SELECT IF(s12bq1a=1).
EXECUTE .
.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Filtered.sav'.

*Selecting the first item declared only if NOT older than five years.

FILTER OFF.
USE ALL.
SELECT IF(s12bq2a<=4).
EXECUTE .

*exclude home, land and shares from computation
FILTER OFF.
USE ALL.
SELECT IF(s12bq0<>319 and s12bq0<>320  and s12bq0<>321).
EXECUTE .

*Tag based on value of expenditure instead of type

*1 is large items and will be depreciated.
IF (s12bq3a>=50000) Type = 1 .
VARIABLE LABELS Type 'Durable type' .
EXECUTE .

*Item 2 is expensed out.
IF (s12bq3a<50000) Type = 2 .
VARIABLE LABELS Type 'Durable type' .
EXECUTE .

*deleting all expendable durables older than 1 year.

FILTER OFF.
USE ALL.
SELECT IF(type=1 or (type=2 and s12bq2a=0) ).
EXECUTE .

*recoding large items purchased in the survey year for storage.

IF (type=1 and s12bq2a=0) type = 3 .
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B1_Filtered.sav'.

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Sec12_B_Agg1.sav'
  /BREAK=hhid type
  /INF1 'Infrequent1' = SUM(s12bq3a).



GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Filtered.sav'.

FILTER OFF.
USE ALL.
SELECT IF(s12bq2b<=4).
EXECUTE .


*exclude home, land and shares from computation
FILTER OFF.
USE ALL.
SELECT IF(s12bq0<>319 and s12bq0<>320  and s12bq0<>321).
EXECUTE .

*Tag based on value of expenditure instead of type

*1 is large items and will be depreciated over a 5 year period.
IF (s12bq3b>=50000) Type = 1 .
VARIABLE LABELS Type 'Durable type' .
EXECUTE .

*Item 2 is expensed out.
IF (s12bq3b<50000) Type = 2 .
VARIABLE LABELS Type 'Durable type' .
EXECUTE .

*deleting all expendable durables older than 1 year.

FILTER OFF.
USE ALL.
SELECT IF(type=1 or (type=2 and s12bq2a=0) ).
EXECUTE .

IF (type=1 and s12bq2b=0) type = 3 .
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B2_Filtered.sav'.


AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Sec12_B_Agg2.sav'
  /BREAK=hhid type
  /INF2 'Infrequent2' = SUM(s12bq3b).

*Alternative computations

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B1_Filtered.sav'.




FILTER OFF.
USE ALL.
SELECT IF(s12bq3a>0).
EXECUTE .



SORT CASES BY
  hhid (A) .

*Matching the month and year of interview.

MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household Survey_2003\Sectional\Date_Interview.sav'
 /RENAME (chiefdom day district ea hhnum rectype region urbrur = d0 d1 d2 d3
  d4 d5 d6 d7)
 /BY hhid
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7.
EXECUTE.



FILTER OFF.
USE ALL.
SELECT IF(s12bq3a>0).
EXECUTE .




SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B2_Combo.sav'.



COMPUTE month2 = month-6 .
EXECUTE .

IF (month2<=0) month2 = month2+12 .
EXECUTE .

IF (month<=6) year2 = year-1 .
EXECUTE .

IF (month>6) year2 = year .
EXECUTE .

COMPUTE year3 = year2-s12bq2a .
EXECUTE .

IF (year3=-1) year3 = 99 .
EXECUTE .

IF (year3=-2) year3 = 98 .
EXECUTE .

SORT CASES BY
  hhid (A) .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B2_Combo.sav'.


SORT CASES BY
  year3 (A) month2 (A) .

MATCH FILES /FILE=*
 /RENAME (month year year2 = d0 d1 d2) year3=Yref month2=MRef
 /TABLE='C:\Sierra Leone_Household Survey_2003\Sectional\DDeflator.sav'
 /RENAME  year=Yref month=MRef
 /BY Yref MRef
 /DROP= d0 d1 d2.
EXECUTE.

SORT CASES BY
  hhid (A) .



MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household Survey_2003\Sectional\Date_Interview.sav'
 /RENAME (chiefdom day district ea hhnum rectype region urbrur = d0 d1 d2 d3
  d4 d5 d6 d7)
 /BY hhid
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7.
EXECUTE.



*Stating everything in 99 prices (deflator actually used to inflate prices).
*Although CPI data goes further back, because of the war, it does not seem reliable.

COMPUTE P_inf = (s12bq3a*deflator)/100 .
EXECUTE .

COMPUTE Age = month-mref .
EXECUTE .


USE ALL.
SELECT IF(p_inf>0).
EXECUTE .

COMPUTE AgeY = year-Yref .
EXECUTE .

IF (agey=-96) AgeY = 4 .
EXECUTE .

IF (agey=-95) AgeY = 5 .
EXECUTE .

COMPUTE agem = (agey*12)+age .
EXECUTE .

SORT CASES BY
  hhid (A) .

COMPUTE DEP = 1-((s12bq4a/p_inf)**(1/(agem/12))) .
EXECUTE .

MEANS
  TABLES=dep  BY s12bq0
  /CELLS MEDIAN  .
*Stuck witht he first series since the aggregate was computed with these deflators.

SORT CASES BY
  hhid (A) .

SORT CASES BY
  s12bq0 (A) .

FILTER OFF.
USE ALL.
SELECT IF(s12bq4a>0).
EXECUTE .

MATCH FILES /FILE=*
 /RENAME  s12bq0=pcode
 /TABLE='C:\Sierra Leone_Household Survey_2003\Sectional\Depreciation.sav'
 /BY pcode.
EXECUTE.

COMPUTE DUse = s12bq4a*(.05+deprec)/(1-deprec) .
EXECUTE .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B2_Combo.sav'.




*On the deflator set anything before Jan. 09 to Jan. 09.



*The deflator file is based on the CPI file.  The base year is 1992 though it has been readjusted to 1999:100.  This was the year when the hostilties ceased.



GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Agg1.sav'.

ADD FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Agg2.sav'
 /RENAME  inf2=inf1.
EXECUTE.

SORT CASES BY
  hhid (A) .

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Sec12_B_AggTot.sav'
  /BREAK=hhid type
  /inf1_1 'Infrequent' = SUM(inf1).

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_AggTot.sav'.


*Saving small items
FILTER OFF.
USE ALL.
SELECT IF(type=2).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Small.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_AggTot.sav'.
FILTER OFF.
USE ALL.

*Selecting long term durables.
SELECT IF(type=3).
EXECUTE .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Lump.sav'.

GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B2_Combo.sav'.

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household'+
 ' Survey_2003\InterFiles\Sec12_B_Large.sav'
  /BREAK=hhid
  /nfdusevl = SUM(duse).


GET FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Large.sav'.

SORT CASES BY
  hhid (A) .

MATCH FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Small.sav'
 /RENAME (type = d0) inf1_1=NFDSAPPL
 /BY hhid
 /DROP= d0.
EXECUTE.

*This is the total of lump sum expenditures during the year of the survey.  Use value is over five years.

MATCH FILES /FILE=*
 /FILE='C:\Sierra Leone_Household Survey_2003\InterFiles\Sec12_B_Lump.sav'
 /RENAME (type = d0) inf1_1=NFDINVES
 /BY hhid
 /DROP= d0.
EXECUTE.


MATCH FILES /FILE=*
 /TABLE='C:\Sierra Leone_Household Survey_2003\Sectional\Misc_Sec11C.sav'
 /RENAME (chiefdom district ea hhnum rectype region s11cq1 s11cq10 s11cq11
  s11cq12 s11cq13 s11cq14 s11cq15 s11cq16 s11cq17 s11cq18 s11cq19 s11cq2
  s11cq20 s11cq21 s11cq22 s11cq23 s11cq24 s11cq3 s11cq4 s11cq5 s11cq6 s11cq7
  s11cq8 s11cq9 s11dq1 s11dq2 s11dq4 s11dq5 urbrur = d0 d1 d2 d3 d4 d5 d6 d7
  d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26
  d27 d28 d29 d30 d31 d32 d33 d34) s11dq3=NFDCEREM
 /BY hhid
 /DROP= d0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 d16 d17 d18 d19
  d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 d32 d33 d34.
EXECUTE.


IF (sysmis(nfdsappl)) nfdsappl = 0 .
EXECUTE .
IF (sysmis(nfdusevl)) nfdusevl = 0 .
EXECUTE .
IF (sysmis(nfdinves)) nfdinves = 0 .
EXECUTE .

IF (sysmis(nfdcerem)) nfdcerem = 0 .
EXECUTE .


*Ceremonial and investgments excluded (current year lump sum covered in durable use)

COMPUTE NFDIQTOT = nfdusevl+nfdsappl .
EXECUTE .



SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\EXNFDINFQ.sav'.
