*FILE PREPARATION SECTION.  CAN BE SKIPPED IF THE .SAV FILE HAS ALREADY BEEN FINALIZED.
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: Household Composition and Weights (Reference file).
*Purpose: To gather the variables from the raw data required for calculating the household reference file.
*Data: Part A : Section 1 Household Roster.
*Procedure:

*open the SPSS file that contains the data for primary variables to compute the household composition.
*see SPSS syntax Part_A.sps for details on the creation of this file.
*--------------------------------------------------------------------------------------------------------------------------.
*BELOW THIS LINE FOR COMPUTATION OF HOUSEHOLD COMPOSITION AND REFERENCE FILE.


*Step 1:  Retrieve file and filter out non household members.  Presumably this means they do not share meals with the household.

GET FILE='C:\Sierra Leone_Household Survey_2003\Sectional\HHRoster_Sec1.sav'.
*impute blanks on HH member.

IF (sysmis(s1q23)) s1q23 = 1 .
EXECUTE .

FILTER OFF.
USE ALL.
SELECT IF(s1q23=1). 
EXECUTE .

*COMPUTE MID = concat(string(hhid,f10.0),string(pid,f2.0)) .
*EXECUTE .


*Step 2A: Calculating FAO_ADQ 

*                          Male    Female
*0-1 yrs                0.27         0.27
*1-3 yrs                0.45         0.45
*4-6 yrs                0.61         0.61
*7-9 yrs                0.73         0.73
*10-12 yrs            0.86         0.78
*13-15 yrs            0.96         0.83
*16-19 yrs            1.02         0.77
*20 and above     1.00         0.73. 


IF (s1q5y<1) FAO_AD = 0.27.
IF (s1q5y>=1 and s1q5y<=3) FAO_AD = 0.45 .
IF (s1q5y>=4 and s1q5y<=6) FAO_AD = 0.61.
IF (s1q5y>=7 and s1q5y<=9) FAO_AD = 0.73.
IF (s1q5y>=10 and s1q5y<=12) and s1q2=1 FAO_AD = 0.86.
IF (s1q5y>=10 and s1q5y<=12) and s1q2=2 FAO_AD = 0.78.
IF (s1q5y>=13 and s1q5y<=15) and s1q2=1 FAO_AD = 0.96.
IF (s1q5y>=13 and s1q5y<=15) and s1q2=2 FAO_AD = 0.83.
IF (s1q5y>=16 and s1q5y<=19) and s1q2=1 FAO_AD = 1.02.
IF (s1q5y>=16 and s1q5y<=19) and s1q2=2 FAO_AD = 0.77.
IF s1q5y>=20 and s1q2=1 FAO_AD = 1.00.
IF s1q5y>=20 and s1q2=2 FAO_AD = 0.73.

EXECUTE .

*Step 2B: Modified Ghana measure which correlated slightly better than above and will be the measure used.

*                          Male    Female
*0-1yrs               0.25         0.25
*1-3 yrs              0.45         0.45
*4-6 yrs              0.62         0.62
*7-10 yrs            0.69         0.69
*11-14 yrs          0.86         0.76
*15-18 yrs          1.03         0.76
*19-25 yrs          1.00         0.76
*26-50 yrs          1.00         0.76
*51 and above     0.79         0.66. 


IF (s1q5y<1) CTRY_AD = 0.25.
IF (s1q5y>=1 and s1q5y<=3) CTRY_AD = 0.45 .
IF (s1q5y>=4 and s1q5y<=6) CTRY_AD = 0.62.
IF (s1q5y>=7 and s1q5y<=10) CTRY_AD = 0.69.
IF (s1q5y>=11 and s1q5y<=14) and s1q2=1 CTRY_AD = 0.86.
IF (s1q5y>=11 and s1q5y<=14) and s1q2=2 CTRY_AD = 0.76.
IF (s1q5y>=15 and s1q5y<=18) and s1q2=1 CTRY_AD = 1.03.
IF (s1q5y>=15 and s1q5y<=18) and s1q2=2 CTRY_AD = 0.76.
IF (s1q5y>=19 and s1q5y<=25) and s1q2=1 CTRY_AD = 1.00.
IF (s1q5y>=19 and s1q5y<=25) and s1q2=2 CTRY_AD = 0.76.
IF (s1q5y>=26 and s1q5y<=50) and s1q2=1 CTRY_AD = 1.00.
IF (s1q5y>=26 and s1q5y<=50) and s1q2=2 CTRY_AD = 0.76.
IF s1q5y>=51 and s1q2=1 CTRY_AD = 0.79.
IF s1q5y>=51 and s1q2=2 CTRY_AD = 0.66.

EXECUTE .


*Step 3: Computing Household Size Aggregate.

AGGREGATE
  /OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\HHSIZE.sav'
  /BREAK=hhid
  /HHSize 'Household Size' = N(pid) /FAO_ADQ 'FAO Equivalent Adult' =
  SUM(fao_ad) /CTRY_ADQ 'Country Equivalent Adult' = SUM(ctry_ad).

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\InterFiles\HHSize_1.sav'.


*Step 3: Including number of children in HH in school.  This is used in education expenses and also included in the HHSIZE aggregate. This assumes that the program
	EXEDU.SPS has been run already.  The order of running is in the file "integrated.sps."

GET FILE='C:\Sierra Leone_Household Survey_2003\AggData\HHSize.sav'.

SORT CASES BY
  hhid (A) .


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\AggData\HHSize.sav'.
