*FILE PREPARATION SECTION.  CAN BE SKIPPED IF THE .SAV FILE HAS ALREADY BEEN FINALIZED.
*Prepared By: Geoffrey Greenwell.
*U.S. Census Bureau.
*geoffrey.parke.greenwell@census.gov.
*tel:(301) 763-3467.

*Title: Part_B_Section.SPS.
*Purpose: To split the raw data files into their respective SPSS files which can be used for section reviews and for computing aggregates.
*Data: Part B 
*Procedure: This section is designed to take the raw ASCII data file and make SPSS sectional files.  

*open the SPSS file that contains the data for primary variables to compute the household composition.
*see SPSS syntax Part_B.sps for details on the creation of this file.
*Will process all the sections for education and store them in the sectional folder.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8A1: Agriculture: Land
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 01.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '01').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Land_Sec8A1.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8A2: Livestock or Fishing
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 03.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '03').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Livestock_Sec8A2.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8A3: Agricultural Equipment
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 05.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '05').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Equipment_Sec8A3.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8B1: Plot detail
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 06.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '06').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Plots_Sec8B1.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8C1: Harvest detail
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 07.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '07').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Harvest_Sec8C1.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8C2: Harvest detail
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 08.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '08').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Harvest_Sec8C2.tmp'
  TABLE /ALL.
EXECUTE.



*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8D: Seasonality
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 09.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '09').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Season_Sec8D.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8E: Househols sales of produce
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 10.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '10').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_OtherSales_Sec8E.tmp'
  TABLE /ALL.
EXECUTE.



*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8F: Agricultural inputs
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 11.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '11').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Inputs_Sec8F.tmp'
  TABLE /ALL.
EXECUTE.



*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8G: Agriculture Processing of produce 
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 12.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '12').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Process_Sec8G.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 8H: Consumption of own produce: Household Expenditure
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 14.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '14').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec8H.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 9A1: Not frequently consumed Non Food: Household Expenditure
*-----------------------------------------------------------------------------------------------------------------------------------


GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 16.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '16').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9A1.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 9A2: Frequently consumed Non Food: Household Expenditure
*-----------------------------------------------------------------------------------------------------------------------------------

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 17.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '17').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9A2.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 9B: Frequently purchased items: Household Expenditure
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 9B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 18.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '18').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9B.tmp'
  TABLE /ALL.
EXECUTE.
*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 9C: Availability
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 9B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 19.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '19').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9C.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10A: Basic Non farm enterprises.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10A.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 20.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '20').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10A.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10B: Expenditures Enterprise 1.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 21.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '21').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10B_1.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10B: Expenditures Enterprise 2.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 23.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '23').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10B_2.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10C: Assets Enterprise 1.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10C.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 24.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '24').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10C_1.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10C: Assets Enterprise 2.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10C.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 25.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '25').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10C_2.tmp'
  TABLE /ALL.
EXECUTE.



*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10D: Revenue of enterprise
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10D.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 26.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '26').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10D.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 10E: Net Income
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 10D.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 27.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '27').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10E.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 11A: Income.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 11A.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 28.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '28').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Income_Sec11A.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 11B: Outward transfers.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 11B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 30.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '30').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Income_Sec11BA.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 11B: Inward transfers
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 11B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 32.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '32').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Income_Sec11BB.tmp'
  TABLE /ALL.
EXECUTE.


*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 11C: Miscellaneous.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 11D.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 33.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '33').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Misc_Sec11C.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 12A: Credit.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 12A.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 35.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '35').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Credit_Sec12A.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 12B: Assets and durable goods.
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 9B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 36.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '36').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Credit_Sec12B.tmp'
  TABLE /ALL.
EXECUTE.

*-----------------------------------------------------------------------------------------------------------------------------------
*SECTION 12C: Savings
*-----------------------------------------------------------------------------------------------------------------------------------

*open the SPSS file that contains all rows of data for Section 9B.

GET
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Part_B.sav'.
EXECUTE.

*select only those rows that have a "rectype" = 38.  This is equivalent to the CSPro TYPEVALUE ID in the data dictionary.

select if (rectype = '38').
execute.

*write the data back out to an ASCII text file with a .tmp extension in the temp directory.

WRITE OUTFILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Credit_Sec12C.tmp'
  TABLE /ALL.
EXECUTE.


*Part II)******************************************************************************************************************************************

*read the .dat file back into SPSS, but now specify variable names and
  columns that are associated with that variable name for this specific 
  record type.  The variable names are the same as what is in the data 
  dictionary except for the "key variables" -  those names were too long
  for SPSS to accept, so they had to be shortened.

*Section 8A1: Agricultural_Land
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Land_Sec8A1.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8AQ1 30-30 S8AQ2 31-31 S8AQ3 32-32 S8AQ4 33-36 S8AQ5 37-37 
  S8AQ6 38-45 S8AQ7 46-46 S8AQ8 47-54 S8AQ9 55-55 S8AQ10 56-63 S8AQ11 64-64 S8AQ12 65-72 S8AQ13 73-73 S8AQ14 74-77 S8AQ15 78-85 
  S8AQ16 86-86 S8AQ17 87-90 S8AQ18 91-98 S8AQ19 99-100. 

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8AQ1 	'Allocated land?'
	/S8AQ2 	'Own Land'
	/S8AQ3 	'Units of land'
	/S8AQ4 	'Land owned by household'
	/S8AQ5 	'Land allocated in last 12 months'
	/S8AQ6 	'Amount paid'
	/S8AQ7 	'Any land allocated in two years prior to last 12 months?'
	/S8AQ8		'Amount paid'
  	/S8AQ9 	'Land lost in the last 12 months'
	/S8AQ10 	'Amount received'
	/S8AQ11 	'Any land lost in two years prior to last 12 months?'	
	/S8AQ12 	'Amount received'
	/S8AQ13 	'Any land rented out in the last 12 months?'
	/S8AQ14 	'How much land was rented out?'
	/S8AQ15 	'Payment in rent'	
	/S8AQ16 	'Land given out for sharecropping?'
	/S8AQ17 	'How much land was sharecropped?'
	/S8AQ18 	'How much did household receive?'
	/S8AQ19	'Proportion of harvest received?'

*add value labels.

val labels 
  /
  /rectype
	1 '8-A1: 'Land'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8AQ1 S8AQ2 S8AQ5 S8AQ7 S8AQ9 S8AQ11 S8AQ13 S8AQ16 
	1 'Yes' 
	2 'No'
/S8AQ3 
	1 'Cropping Rate'
	2 'Acre'
	3 'Rope'
	4 'Other'.

EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8AQ19
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri__Land_Sec8A1.sav'.



*Section 8A2: Agricultural_Livestock and Fishing
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Livestock_Sec8A2.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8AQ0 14-15 S8AQ21 16-16 S8AQ22 17-21 S8AQ22U 22-22  S8AQ23 23-31
  S8AQ24 32-32 S8AQ25 33-39 S8AQ25U 40-40 S8AQ26 41-49 S8AQ27 50-50 S8AQ28 51-57 S8AQ28U 58-58 S8AQ29 59-67 S8AQ30 68-68 S8AQ31 69-77.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8AQ0 	'Animal Code'
	/S8AQ21	'Raised in the last 12 months?'
	/S8AQ22	'Quantity raised?'
	/S8AQ22U 	'Units raised'
	/S8AQ23 	'Market value of unit'
  	/S8AQ24	'Sold in the last 12 months?'
	/S8AQ25	'How many sold?'
	/S8AQ25U	'Units sold?'
	/S8AQ26	'Total value sold'
	/S8AQ27	'Bought in the last 12 months?'
	/S8AQ28	'How many bought?'
	/S8AQ28U	'Units bought?'
	/S8AQ29	'Total value of purchases'
	/S8AQ30	'Rented out in the last 12 months?'
	/S8AQ31	'Amount received from renting out'.

*add value labels.

val labels 
  /
  /rectype
	3 '8-A2: Livestock'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8AQ0 
	1 'Work Oxen'
	2 'Cattle'
	3 'Sheep'
	4 'Goats'
	5 'Pigs'
	6 'Rabbits'
	7 'Chicken'
	8 'Other poultry'
	9 'Other livestock'
	10 'Fish'
	11 'Crab'
	12 'Other'
/S8AQ21 S8AQ24 S8AQ27 S8AQ30	
	1 'Yes'
	2 'No'
/S8AQ22U S8AQ25U S8AQ28U	
	1 'Crate'
	2 'Bowl'
	3 'Basket'
	4 'Other'.
	
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8AQ31
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Livestock_Sec8A2.sav'.


*Section 8A3: Agricultural_Equipment
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Equipment_Sec8A3.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8AQ0 14-15 S8AQ33 16-16  S8AQ34 17-19  S8AQ35 20-28 S8AQ36 29-29 
  S8AQ37 30-38 S8AQ38 39-39 S8AQ39 40-48.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8AQ0 	'Equipment Code'
	/S8AQ33 	'Does anyone own?'
	/S8AQ34 	'How many'
	/S8AQ35 	'Market value'
	/S8AQ36 	'Rented out in last 12 months?'
	/S8AQ37 	'Value of rental'
	/S8AQ38 	'Sold in last 12 months?'
	/S8AQ39 	'Value of sales?'.
	

*add value labels.

val labels 
  /
  /rectype
	5 '8-A3: Equipment'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8AQ0 
	21 'Tractor&Accessories'
	22 'Power Tillers'
	31 'Hand Hoes'
	41 'Grater'
	42 'Threshers'
	51 'Sprayer'
	61 'Winnowers'
	62 'Rice Mill'
	63 'Fishing Net'
	64 'Safety Equipment'
	65 'Cutlasses'
	66 'Other'
/S8AQ33 S8AQ36 S8AQ38
	1 'Yes'
	2 'No'
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8AQ39
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Equipment_Sec8A3.sav'.


*Section 8B1: Agricultural_Plots
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Plots_Sec8B1.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8BQ1 14-15 S8BQ2 16-17 S8BQ3 18-19 S8BQ4 20-23 S8BQ5 24-24
  S8BQ6 25-25 S8BQ7 26-34 S8BQ8 35-35 S8BQ9 36-44 S8BQ10 45-46 S8BQ11 47-47 S8BQ12A 48-49 S8BQ12B 50-51 S8BQ13A 52-53 S8BQ13B 54-55 
  S8BQ13C 56-57 S8BQ13D 58-59.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
 	/S8BQ1 	'ID of farm holder'
	/S8BQ2 	'ID of person interviewed'
	/S8BQ3 	'Farm number'
	/S8BQ4 	'Farm size'
	/S8BQ5 	'Does the household own the farm?'
	/S8BQ6 	'Does the household have any rights to dispose of the farm?'
	/S8BQ7 	'How much is the plot worth?'
	/S8BQ8 	'How did you obtain the land?'
	/S8BQ9		'Cost of rental over the last 12 months?'
  	/S8BQ10 	'Proportion to landlord?'
	/S8BQ11 	'Was the farm cultivated in the last 12 months?'
	/S8BQ12A 	'What crops (1) were growing 12 months ago?'
	/S8BQ12B 	'What crops (2) were growing 12 months ago?'
	/S8BQ13A 	'What crops (1) planted this year?'
	/S8BQ13B 	'What crops (2) planted this year?'
	/S8BQ13C 	'What crops (3) planted this year?'
	/S8BQ13D	'What crops (4) planted this year?'.

*add value labels.

val labels 
  /
  /rectype
	6 '8-B1:Plots'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8BQ5 
	1 'Yes with Deed'
	2 'Yes without Deed'
	3 'No'
/S8BQ6 
	1 'Sell'
	2 'Security'
	3 'Both'
	4 'No rights'
/S8BQ8
	1 'Rented'
	2 'Sharecropping'
	3 'Free of charge'
	4 'Distributed'
	5 'Other'
/S8BQ9
	1 'Rented'
	2 'Sharecropping'
	3 'Free of charge'
	4 'Distributed'
	5 'Other'
/S8BQ10 
	20 '20%'
	25 '25%'
	33 '33%'
	50 '50%'
	67 '66%'
/S8BQ11
	1 'Yes'
	2 'No '
/S8BQ12A S8BQ12B S8BQ13A S8BQ13B S8BQ13C S8BQ13D 
	1 'Cocoa'
	2 'Coffee'
	3 'Rubber'
	4 'Coconut'
	5 'Palm oil'
	6 'Plantain'
	7 'Bananas'
	8 'Oranges'
            9 'Other Foods'
	10 'Sorghum/Couscous'
	11 'Cola Nuts'
	12 'Palm Kernel'
	13 'Cotton'
	14 'Ground nut'
	15 'Tobacco'
	16 'Pine Apple'
	17 'Sugar Cane'
	18 'Cassava'
	19 'Yam'
	20 'Coco Yam'
	21 'Sweet Potatoes'
	22 'Maize'
	23 'Rice'
	24 'Sorghum'
	25 'Tomatoes'
	26 'Okra'
	27 'Garden Egg'
	28 'Beans/Peas'
	29 'Pepper'
	30 'Leafy Vegetables'
	31 'Other Vegetables'
	32 'Other Crops'
	33 'Onions'
	34 'Avocado Pear'
	35 'Mango'
	36 'Pawpaw'
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8BQ13D
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri__Plots_Sec8B1.sav'.


*Section 8C1: Agricultural_Harvest Detail
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Harvest_Sec8C1.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8CQ1 14-15 S8CQ2 16-17 S8CQ3A 18-22 S8CQ3B 23-24 S8CQ4A 25-29 
  S8CQ4B 30-31 S8CQ5 32-32 S8CQ6 33-33 S8CQ7A 34-38 S8CQ7B 39-40 S8CQ8 41-49 S8CQ9 50-50 S8CQ10A 51-55 S8CQ10B 56-57 S8CQ11 58-66 
  S8CQ12 67-70 S8CQ13 71-79 S8CQ14A 80-84 S8CQ14B 85-86 S8CQ15A 87-91 S8CQ15B 92-93 S8CQ16A 94-98 S8CQ16B 99-100 S8CQ17M 101-103 
  S8CQ17F 104-106.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8CQ1 	ID of farm holder'
	/S8CQ2 	'Crop harvested'
	/S8CQ3A 	'How much harvested?'
	/S8CQ3B 	'Unit harvested'
	/S8CQ4A 	'How much given to the landlord?'
	/S8CQ4B 	'Units given to the landlord'
	/S8CQ5 	'Sell any produce in the last 12 months?'
	/S8CQ6 	'Main outlet of sales?'
	/S8CQ7A	'How much sold?'
  	/S8CQ7B 	'Unit of sale'
	/S8CQ8 	'Value of sales'
	/S8CQ9 	'How promptly were you paid?'
	/S8CQ10A 	'How much did you sell through other outlets?'
	/S8CQ10B 	'Unit of sales in other outlets'
	/S8CQ11 	'Value of sales through other outlets'
	/S8CQ12 	'Acreage of farm?'
	/S8CQ13 	'Total value of all harvested?'
	/S8CQ14A 	'How much was processed by the household?'
	/S8CQ14B 	'Unit of item processed'
	/S8CQ15A 	'How much was used as seeds?'
	/S8CQ15B 	'Units of items used as seeds'
	/S8CQ16A 	'How much of the harvest was given to labor?'
	/S8CQ16B 	'Unit given to labor'
	/S8CQ17M 	'Men employed by farm'
	/S8CQ17F	'Women employed by farm'.

*add value labels.

val labels 
  /
  /rectype
	7 '8-C: Harvest Detail'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8CQ2 
	1 'Cocoa'
	2 'Coffee'
	3 'Rubber'
	4 'Coconut'
	5 'Palm oil'
	6 'Plantain'
	7 'Bananas'
	8 'Oranges'
            9 'Other Foods'
	10 'Sorghum/Couscous'
	11 'Cola Nuts'
	12 'Palm Kernel'
	13 'Cotton'
	14 'Ground nut'
	15 'Tobacco'
	16 'Pine Apple'
	17 'Sugar Cane'
	18 'Cassava'
	19 'Yam'
	20 'Coco Yam'
	21 'Sweet Potatoes'
	22 'Maize'
	23 'Rice'
	24 'Sorghum'
	25 'Tomatoes'
	26 'Okra'
	27 'Garden Egg'
	28 'Beans/Peas'
	29 'Pepper'
	30 'Leafy Vegetables'
	31 'Other Vegetables'
	32 'Other Crops'
	33 'Onions'
	34 'Avocado Pear'
	35 'Mango'
	36 'Pawpaw'
/S8CQ3B S8CQ4B S8CQ7B S8CQ10B S8CQ14B S8CQ15B S8CQ16B 
	0 'None'
	1 'Pound(s)'
	2 'Kilogram(s)'
	3 'Ton(s)'
	4 'Salt Bag(s)'
	5 'Rice Bag(s)'
	6 'Sheet(s)'
	7 'Basket(s)'
	8 'Three Pence Pan'
	9 'American Tin(s)'
	10 'Tree(s)'
	11 'Stick(s)'
	12 'Bundle(s)'
	13 'Batta(5 Gallons)'
	14 'Litre(s)'
	15 'Gallon(s)'
	16 'Pint(s)'
	17 'Bunch'
	18 'Nuts'
	19 'Fruits'
	20 'Logs'
	21 'Kerosine tin'
	22 'Butter cup'
	23 'Tuber'
	24 'Fingers'
	25 'Bushel'
	26 'Drum'
	27 'Other'
/S8CQ5 
	1 'Yes'
	2 'No'
/S8CQ6 
	1 'Contractor'
	2 'Farm Gate'
	3 'Market Trader'
	4 'Consumer State'
	5 'Trading'
	6 'Organisation'
/S8CQ9 
	1 'At time of sale'
	2 'Within 1 week'
	3 'Within 1 month'
	4 'Over 1 month'.
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8CQ17F
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Harvest_Sec8C1.sav'.

*Section 8C2: Agricultural_Harvest Detail
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Harvest_Sec8C2.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8CQ18 14-15 S8CQ19 16-17 S8CQ20 18-18 S8CQ21A 19-23 S8CQ21B 24-25 
  S8CQ22 26-34 S8CQ23A 35-39  S8CQ23B 40-41 S8CQ24 42-42 S8CQ25A 43-47 S8CQ25B 48-49 S8CQ26 50-58 S8CQ27A 59-63 S8CQ27B 64-65 
  S8CQ28A 66-68 S8CQ28B 69-70. 

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8CQ18 	ID of farm holder'
	/S8CQ19 	'Harvested in the last 12 months?'
	/S8CQ20 	'Harvested in the last 2 weeks?'
	/S8CQ21A 	'Quantity harvested'
	/S8CQ21B 	'Unit harvested'
	/S8CQ22 	'Value of all harvested in alst 2 weeks?'
	/S8CQ23A	'How much given to the landlord in past two weeks?'
  	/S8CQ23B 	'Unit given to the landlord'
	/S8CQ24 	Any sold in the last two weeks?'
	/S8CQ25A 	'How much sold in the last two weeks?'
	/S8CQ25B 	'Unit sold'
	/S8CQ26 	'Total value of the sales'
	/S8CQ27A 	'How much was processed in the last two weeks?'
	/S8CQ27B 	'Unit processed'
	/S8CQ28A 	'How much was given to labour in the last two weeks?'
	/S8CQ28B 	'Unit given to labor'

*add value labels.

val labels 
  /
  /rectype
	8 '8-C2: Harvest Detail'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8CQ19 
	1 'Cocoa'
	2 'Coffee'
	3 'Rubber'
	4 'Coconut'
	5 'Palm oil'
	6 'Plantain'
	7 'Bananas'
	8 'Oranges'
            9 'Other Foods'
	10 'Sorghum/Couscous'
	11 'Cola Nuts'
	12 'Palm Kernel'
	13 'Cotton'
	14 'Ground nut'
	15 'Tobacco'
	16 'Pine Apple'
	17 'Sugar Cane'
	18 'Cassava'
	19 'Yam'
	20 'Coco Yam'
	21 'Sweet Potatoes'
	22 'Maize'
	23 'Rice'
	24 'Sorghum'
	25 'Tomatoes'
	26 'Okra'
	27 'Garden Egg'
	28 'Beans/Peas'
	29 'Pepper'
	30 'Leafy Vegetables'
	31 'Other Vegetables'
	32 'Other Crops'
	33 'Onions'
	34 'Avocado Pear'
	35 'Mango'
	36 'Pawpaw'
/S8CQ20 S8CQ24 
	1 'Yes'
	2 'No'
/S8CQ21B S8CQ23B S8CQ25B S8CQ27B S8CQ28B
	0 'None'
	1 'Pound(s)'
	2 'Kilogram(s)'
	3 'Ton(s)'
	4 'Salt Bag(s)'
	5 'Rice Bag(s)'
	6 'Sheet(s)'
	7 'Basket(s)'
	8 'Three Pence Pan'
	9 'American Tin(s)'
	10 'Tree(s)'
	11 'Stick(s)'
	12 'Bundle(s)'
	13 'Batta(5 Gallons)'
	14 'Litre(s)'
	15 'Gallon(s)'
	16 'Pint(s)'
	17 'Bunch'
	18 'Kerosene Tin(s)'
	19 'Butter Cap(s)'
	20 'Finger(s)'
	21 'Bushel(s)'
	22 'Tuber(s)'
	23 'All'.


EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8CQ28B
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Harvest_Sec8C2.sav'.




*Section 8D: Seasonality

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Season_Sec8D.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8DQ0 14-15 S8DQ1 16-16 S8DQ2JAN 17-17 S8DQ2FEB 18-18  S8DQ2MAR 19-19
  S8DQ2APR 20-20 S8DQ2MAY 21-21 S8DQ2JUN 22-22 S8DQ2JUL 23-23 S8DQ2AUG 24-24 S8DQ2SEP 25-25 S8DQ2OCT 26-26 S8DQ2NOV 27-27 
  S8DQ2DEC 28-28 S8DQ3JAN 29-29 S8DQ3FEB 30-30 S8DQ3MAR 31-31 S8DQ3APR 32-32 S8DQ3MAY 33-33 S8DQ3JUN 34-34 S8DQ3JUL 35-35 S8DQ3AUG 36-36
  S8DQ3SEP 37-37 S8DQ3OCT 38-38 S8DQ3NOV 39-39 S8DQ3DEC 40-40 S8DQ4JAN 41-41 S8DQ4FEB 42-42 S8DQ4MAR 43-43  S8DQ4APR 44-44
  S8DQ4MAY 45-45 S8DQ4JUN 46-46 S8DQ4JUL 47-47 S8DQ4AUG 48-48 S8DQ4SEP 49-49 S8DQ4OCT 50-50 S8DQ4NOV 51-51 S8DQ4DEC 52-52
  S8DQ5A 53-58 S8DQ5B 59-60 S8DQ6A 61-66 S8DQ6B 67-68

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8DQ0 	'Crop Code'
	/S8DQ1 	'Grown in the last 12 months?'
	/S8DQ2JAN 	'January harvest'
	/S8DQ2FEB 	'February harvest'
	/S8DQ2MAR	'March harvest'
  	/S8DQ2APR 	'April harvest'
	/S8DQ2MAY 	'May harvest'
	/S8DQ2JUN 	'June harvest'
	/S8DQ2JUL  	'July harvest'
	/S8DQ2AUG 	'August harvest'
	/S8DQ2SEP 	'September harvest'
	/S8DQ2OCT 	'October harvest'
	/S8DQ2NOV 	'November harvest'
	/S8DQ2DEC 	'December harvest'
	/S8DQ3JAN 	'January sold'
	/S8DQ3FEB 	'February sold'
	/S8DQ3MAR	'March sold'
  	/S8DQ3APR 	'April sold'
	/S8DQ3MAY 	'May sold'
	/S8DQ3JUN 	'June sold'
	/S8DQ3JUL 	'July sold'
	/S8DQ3AUG 	'August sold'
	/S8DQ3SEP 	'September sold'
	/S8DQ3OCT 	'October sold'
	/S8DQ3NOV 	'November sold'
	/S8DQ3DEC 	'December sold'
	/S8DQ4JAN 	'January consumed'
	/S8DQ4FEB 	'February consumed'
	/S8DQ4MAR	'March consumed'
  	/S8DQ4APR 	'April consumed'
	/S8DQ4MAY 	'May consumed'
	/S8DQ4JUN 	'June consumed'
	/S8DQ4JUL 	'July consumed'
	/S8DQ4AUG 	'August consumed'
	/S8DQ4SEP 	'September consumed'
	/S8DQ4OCT 	'October consumed'
	/S8DQ4NOV 	'November consumed'
	/S8DQ4DEC 	'December consumed'
	/S8DQ5A 	'What is the quantity stored?'
	/S8DQ5B 	'Units stored'
	/S8DQ6A 	'Quantity stored 12 months ago?'
	/S8DQ6B	'Units stored'.
	

*add value labels.

val labels 
  /
  /rectype
	9 '8-D: Seasonality
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8DQ0 
	1 'Cocoa'
	2 'Coffee'
	3 'Rubber'
	4 'Coconut'
	5 'Palm oil'
	6 'Plantain'
	7 'Bananas'
	8 'Oranges'
            9 'Other Foods'
	10 'Sorghum/Couscous'
	11 'Cola Nuts'
	12 'Palm Kernel'
	13 'Cotton'
	14 'Ground nut'
	15 'Tobacco'
	16 'Pine Apple'
	17 'Sugar Cane'
	18 'Cassava'
	19 'Yam'
	20 'Coco Yam'
	21 'Sweet Potatoes'
	22 'Maize'
	23 'Rice'
	24 'Sorghum'
	25 'Tomatoes'
	26 'Okra'
	27 'Garden Egg'
	28 'Beans/Peas'
	29 'Pepper'
	30 'Leafy Vegetables'
	31 'Other Vegetables'
	32 'Other Crops'
	33 'Onions'
	34 'Avocado Pear'
	35 'Mango'
	36 'Pawpaw'
/S8DQ1
	1 'Yes'
	2 'No' 
/S8DQ5B  S8DQ6B
	0 'None'
	1 'Pound(s)'
	2 'Kilogram(s)'
	3 'Ton(s)'
	4 'Salt Bag(s)'
	5 'Rice Bag(s)'
	6 'Sheet(s)'
	7 'Basket(s)'
	8 'Three Pence Pan'
	9 'American Tin(s)'
	10 'Tree(s)'
	11 'Stick(s)'
	12 'Bundle(s)'
	13 'Batta(5 Gallons)'
	14 'Litre(s)'
	15 'Gallon(s)'
	16 'Pint(s)'
	17 'Bunch'
	18 'Kerosene Tin(s)'
	19 'Butter Cap(s)'
	20 'Finger(s)'
	21 'Bushel(s)'
	22 'Tuber(s)'
	23 'All'.
	
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8DQ6B 
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Season_Sec8D.sav'.



*Section 8E: Agricultural_Other sales

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_OtherSales_Sec8E.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8EQ1 14-20 S8EQ2 21-27 S8EQ3 28-34 S8EQ4 35-41 S8EQ5 42-48 S8EQ6 49-55 
  S8EQ7 56-62 S8EQ8 63-69 S8EQ9 70-76 S8EQ10 77-83 S8EQ11 84-90 S8EQ12 91-97 S8EQ13 98-104.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8EQ1 	'Hunting'
	/S8EQ2 	'Honey'
	/S8EQ3 	'Palm wine etc.'
	/S8EQ4 	'Fruit, berries etc.'
	/S8EQ5 	'Milk'
	/S8EQ6 	'Other dairy products'
	/S8EQ7 	'Eggs'
	/S8EQ8		'Hides'
  	/S8EQ9 	'Mushrooms'
	/S8EQ10 	'Palm oil'
	/S8EQ11 	'Palm kernel'
	/S8EQ12 	'Nut oil'
	/S8EQ13	'Firewood'.


*add value labels.

val labels 
  /
  /rectype
	10 '8-E: Sale of other produce'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'.


EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8EQ13 
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_OtherSales_Sec8E.sav'.


*Section 8F: Agricultural_Inputs
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Inputs_Sec8F.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8FQ0 14-15 S8FQ1 16-16 S8FQ2 17-26 S8FQ3 27-27 S8FQ4 28-28.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8FQ0  	'Input code'
	/S8FQ1 	'Spent in  the last 12 months?'
	/S8FQ2 	'Spent in cash or in-kind?'
	/S8FQ3 	'Source of input?'
	/S8FQ4		'Unobtainable during last 12 months?'

*add value labels.

val labels 
  /
  /rectype
	11 '8-F: Agricultural inputs'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8FQ0  
	1 'Inorganic fertilizer'
	2 'Organic fertilizer'
	3 'Insecticide'
	4 'Herbicide'
	5 'Storage of crops'
	6 'Purchase of seeds, seedlings'
	7 'Irrigation'
	8 'Bags, containers, string, ties etc.'
	9 'Petrol, diesel, oil'
	10 'Spare parts'
	11 'Hired labour'
	12 'Transport'
	13 'Renting animals'
	14 'Renting equipment'
	15 'Local hand tools'
	16 'Imported hand tools'
	17 'Repair and maintenance'
	18 'Other'
	51 'Animal feed including salt'
	52 'Veterinary services and medical'
	53 'Paid labour for herding'
	54 'Maintenance of pens and stables'
	55 'Transport of animal feed'
	56 'Comission on sale of animal'
	57 'Compensation for damage caused by animal'
	58 'Other livestock costs'
	59 'Hired labour (livestock)'
	61 'Fuel for fishing'
	62 'Hired labour for fishing'
	63 'Spare parts for fishing'
	64 'Repairs and maitenance for fishing'
	65 'Mining equipment'
	66 'Other costs'
/S8FQ1 S8FQ4
	1 'Yes'
	2 'No'
/S8FQ3 
	1 'Private Sector'
	2 'Cooperative'
	3 'Minist. of Agric'
	4 'NGOs'
	5 'Other'.
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8FQ4 
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Inputs_Sec8F.sav'.


*Section 8G: Agricultural_Processing of produce
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Agri_Process_Sec8G.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8GQ1 14-15 S8GQ2 16-17 S8GQ3 18-19 S8GQ4 20-21 S8GQ5 22-22 S8GQ6A 23-25
  S8GQ6B 26-27 S8GQ7 28-36 S8GQ8 37-37 S8GQ9 38-46 S8GQ10 47-47 S8GQ11A 48-52 S8GQ11B 53-54 S8GQ12 55-63 S8GQ13 64-72. 

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S8GQ1 	'ID of person responsible'
	/S8GQ2 	'ID of person interviewed'
	/S8GQ3 	'Code of item processed'
	/S8GQ4 	'Months engaged in activity'
	/S8GQ5 	'Made any in the past 2 weeks?'
	/S8GQ6A 	'Quantity in the last two weeks'
	/S8GQ6B 	'Unit produced in the last two weeks'
	/S8GQ7 	'Labour costs'
	/S8GQ8		'Where did raw materials come from?'
  	/S8GQ9 	'What other costs incurred in the last 2 weeks?'
	/S8GQ10 	'Sell any in the last 2 weeks?'
	/S8GQ11A 	'Quantity sold'
	/S8GQ11B 	'Units sold'
	/S8GQ12 	'Value of total sales'
	/S8GQ13 	'Unit value'

*add value labels.

val labels 
  /
  /rectype
	12 '8-G: Processing of produce'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8GQ3 
	1 'Maize flour'
	2 'Flour from other grains'
	3 'Husked or polished rice'
	4 'Home brewed drink'
	5 'Cassava flour'
	6 'Shelled groundnuts'
	7 'Processed fish'
	8 'Gari'
	9 'Shea butter'
	10 'Other nuts'
	11 'Palm kernel oil'
	12 'Coconut oil'
	13 'Palm oil'
	14 'Palm kernel oil'
/S8GQ5 S8GQ10 
	1 'Yes'
	2 'No'
/S8GQ6B S8GQ11B  
	1 'Pound(s)'
	2 'Kilogram(s)'
	3 'Ton(s)'
	4 'Mini Bag(s)'
	5 'Maxi Bag(s)'
	6 'Sheet(s)'
	7 'Basket(s)'
	8 'Bowl(s)'
	9 'American Tin(s)'
	10 'Tree(s)'
	11 'Stick(s)'
	12 'Bundle(s)'
	13 'Barrel(s)'
	14 'Litre(s)'
	15 'Gallon(s)'
	16 'Beer Bottle(s)'
	17 'Bunch'
	18 'Nut(s)'
	19 'Fruit(s)'
	20 'Log(s)'
	21 'Margarine Tin(s)'
	22 'All'
/S8GQ8
	1 'Own produce'
	2 'Purchased'
	3 'Gift'
	4 'Other'.

EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S8GQ13
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Agri_Process_Sec8G.sav'.




*Section 8H: Consumption of own produce
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec8H.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S8HQ0 14-16 S8HQ1 17-17 S8HQ2 18-19 S8HQ3 20-22 S8HQ4 23-25 
  S8HQ5 26-28 S8HQ6 29-31 S8HQ7 32-34 S8HQ8 35-37 S8HQ9 38-39 S8HQ10 40-46 S8RC 47-49. 

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	S8HQ0		'Product Code'
	S8HQ1		'Did Consume?'
	S8HQ2		'Number of Months consumed'
	S8HQ3		'Visit 1'
	S8HQ4		'Visit 2'
	S8HQ5		'Visit 3'
	S8HQ6		'Visit 4'
	S8HQ7		'Visit 5'
	S8HQ8		'Visit 6'
	S8HQ9		'Units'
	S8HQ10	'Unit value'
	S8RC		'Recoded value'.
	
*add value labels.

val labels 
  /
  /rectype
	14 '8-H: Consumption of Own Produce'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S8HQ0
	001 'Fresh Pepper '
	002 'Salt  '
	003 'Pepper (Dried) '
	004 'Spices and other condiments '
	005 'Other miscellaneous food '
	006 'Bitter Kola '
	007 'Kola Nut '
	099 'Cookry '
	100 'Bread and Buns '
	101 'Maize-Cob (fresh) '
	102 'Maize-Flour Dough '
	103 'Millet Grain '
	104 'Millet Flour '
	105 'Rice (Paddy Grain) Local '
	106 'Rice (Paddy Grain) Imported '
	107 'Guinea Corn '
	108 'Sorghum '
	109 'Bananas '
	110 'Cassava Roots '
	111 'Cassava Gari '
	112 'Plantain '
	113 'Sweet Potato '
	114 'Coco Yams '
	115 'Yams '
	116 'Other Grains and flours '
	117 'Cassava (Other Forms) '
	118 'Other Roots and Tubers '
	119 'Other starchy products '
	200 'Bacon '
	201 'Fresh Cow meat (no bone) '
	202 'Chicken '
	203 'Mutton '
	204 'Pork '
	205 'Meat Sausage '
	206 'Bush Fowl '
	207 'Guinea Fowl '
	208 'Other domestic poultry '
	209 'Fresh Cow Meat (Bone) '
	210 'Goat '
	211 'Pigs Feet '
	212 'Ham '
	213 'Other domestic meat '
	214 'Wild meat '
	300 'Dried Fish '
	301 'Smoked Fish '
	302 'Shell Fish '
	303 'Fried Fish '
	304 'Fresh Fish '
	305 'Canned Fish '
	400 'Eggs '
	401 'Milk '
	402 'Other Egg '
	403 'Milk Powder '
	404 'Baby Milk '
	405 'Tinned Milk (unsweetened) '
	406 'Other Milk Products '
	500 'Palm Oil '
	501 'Palm Kernel Oil '
	502 'Groundnut oil '
	503 'Coconut Oil '
	504 'Other nuts and seeds '
	505 'Margarine '
	506 'Other vegetable oil/fats '
	507 'Animal fats '
	508 'Palm Nuts '
	509 'Ground Nuts (roasted or raw) '
	510 'Coconuts '
	511 'Shea Butter '
	600 'Watermelon '
	601 'Paw paw '
	602 'Oranges Tangerine '
	603 'Mangoes '
	604 'Pineapples '
	605 'Other Fresh Fruit '
	606 'Canned fruit '
	700 'Bambara Beans '
	701 'Cowpeas (Small) '
	702 'Broad beans '
	703 'Other pulses or legumes '
	704 'Avocado pears '
	705 'Tomatoes '
	706 'Onions '
	707 'Carrots '
	708 'Okra '
	709 'Gardens eggs cucumbers '
	710 'Cabbage/Lettuce '
	711 'Spinach/Other Leafy Vegetables '
	712 'Other vegetables '
	713 'Cabbage '
	800 'Biscuits '
	801 'Honey '
	802 'Sugar '
	803 'Ice cream lollipop '
	804 'Jams '
	805 'Confectionary not frozen '
	900 'Fruit juices '
	901 'Coffee '
	902 'Chocolate '
	903 'Tea '
	904 'Softdrinks '
	905 'Local and imported beer '
	906 'Palm Wine '
	907 'Bamboo Wine '
	908 'Omole and local spirits '
	909 'Gin/Sassman '
	910 'Other alcoholic '
	911 'Other non-alcoholic '
	998 'Health care personal; hygiene '
	999 'Tobacco '
/S8HQ1
	1 'Yes'
	2 'No'
/S8HQ2
	1 '1 Month'
	2 '2 Months'
	3 '3 Months'
	4 '4 Months'
	5 '5 Months'
	6 '6  Months'
	7 '7 Months'
	8 '8 Months'
	9 '9 Months' 
	10 '10 Months'
	11 '11 Months'
	12 '12 Months'
/S8HQ9
	0 'None'
	1 'Pounds'
	2 'Kilogram'
	3 'Ton'
	4 'Salt bag'
	5 'Rice bag'
	6 'Sheet'
	7 'Basket'
	8 'Three pence pan'
	9 'American tin'
	10 'Tree'
	11 'Stick'
	12 'Bundle'
	13 'Batta'
	14 'Litre'
	15 'Gallon'
	16 'Pint'
	17 'Bunch'
	18 'Nut'
	19 'Fruits'
	20 'Log'
	21 'Kerosene Tin'
	22 'Butter Cup'
	23 'Tuber'
	24 'Fingers'
	25 'Bushel'
	26 'Drum'
	27 'Other'
	  
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

COMPUTE S8HQ0 =  S8RC.
EXECUTE .



FREQUENCIES
  VARIABLES=rectype to S8HQ10
  /ORDER=  ANALYSIS .

*Recode to common codes.


SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec8H.sav'.
   
*Section 9A1:Infrequent non food


SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9A1.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S9A1Q0 14-16 S9A1Q1 17-17 S9A1Q2 18-20 S9A1Q3 21-27 S9A1Q4 28-34 .

*data dictionary names and lengths do not conform in Q4-Q6.  This is the reason for stating them out of order.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S9A1Q0	'Product Code'
	/S9A1Q1	'Did purchase 12 months?'
	/S9A1Q2	'How many times (12 months)?'
	/S9A1Q3	'How much spent (12 months)?'
	/S9A1Q4	'How much spent (3 months)??'
	
*add value labels.

val labels 
  /
  /rectype
	16 '9A1: Infrequent Non food'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S9A1Q0
	201 ' Cotton ' 
	202 ' Silk ' 
	203 ' Hand Loomed Cloth ' 
	204 ' Polyester Material ' 
	205 ' All Other Clothing Material (Natural fibre or otherwise) ' 
	206 ' Tailoring Charges ' 
	207 ' Suit / Safari Suit ' 
	208 ' Smock or Other Hand Woven Garment ' 
	209 ' Dress (ladies/girls) ' 
	210 '  Trousers  Slacks  Shorts  Blouse  Shirts  ' 
	211 ' Underwear (Incl.Vests and Underpants) ' 
	212 ' Other Readymade Clothes ' 
	213 ' Mens Shoes ' 
	214 ' Mens Slippers ' 
	215 ' Ladies Shoes ' 
	216 ' Ladies Slippers ' 
	217 ' Boys shoes ' 
	218 ' Girls shoes ' 
	219 ' Repair of footwear ' 
	220 ' House / Property Rates ' 
	221 ' Basic Rates ' 
	222 ' Bed sheets  Bed Cover  Blanket  Curtains   ' 
	223 ' Mattress  Pillow & Cases  ' 
	224 ' Bed / Sleeping Mats ' 
	225 ' Chair ' 
	226 ' Table ' 
	227 ' Carpet and other floor covering ' 
	228 ' Cupboards/Wardrobes Repairs ' 
	229 ' Other furniture and fixtures ' 
	230 ' Electric fan ' 
	231 ' Air Conditioner /  Air Cooler ' 
	232 ' Fridge and Freezers ' 
	233 ' Electric Iron '  
	234 ' Washing Machine and dryer '  
	235 ' Electric Kettle '  
	236 ' Gas or Electric Stoves '  
	244 ' Spectacles and contact Lenses '  
	245 ' Wheelchairs '  
	246 ' Crutches '  
	247 ' Other appliances (medical) '  
	248 ' Dentist fees '  
	249 ' Nurse  Midwives etc.Fees  '  
	250 ' Traditional and  Spiritual Healers '  
	251 ' Pharmacist Fees (Consultation) '  
	252 ' Other Medical Practitioners '  
	253 ' Headache pills '  
	254 ' Other medicines '  
	266 ' Cars or Motor Vehicle '  
	267 ' Motor Cycles '  
	268 ' Bicycles '  
	269 ' Tyres '  
	270 ' Radio   Wireless and Cassette/Radio  '  
	271 ' T.V. Sets  Video  Video  Camera  '  
	272 ' Other (phonogram  C/D players  music systems)  '  
	273 ' Camera and photographic equipment '  
	274 ' Sports Equipments '  
	275 ' Musical Instruments '  
	276 ' Jewellery(watches  rings etc)  '  
	277 ' Other personal goods   '  
/S9A1Q1
	1 'Yes'
	2 'No'.
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S9A1Q4
  /ORDER=  ANALYSIS .


*Need to recode product codes to conform with a reclassification scheme due to different codes for
*purchases, own conspumption and the pricing questionnaire.



SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9A1.sav'.
   
*Section 9A2: Frequently Non food purchased items

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9A2.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S9A2Q0 14-16 S9A2Q1 17-17 S9A2Q2 18-20 S9A2Q3 21-27 S9A2Q4 35-35 
  S9A2Q5 36-38 S9A2Q6 28-34 .

*data dictionary names and lengths do not conform in Q4-Q6.  This is the reason for stating them out of order.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S9A2Q0		'Product Code'
	/S9A2Q1		'Did purchase 12 months?'
	/S9A2Q2		'How many times (12 months)?'
	/S9A2Q3		'How much spent?'
	/S9A2Q4		'Did purchase 3 months?'
	/S9A2Q5		'How many times (3 months)?'
	/S9A2Q6		'How much spent?'
	

*add value labels.

val labels 
  /
  /rectype
	17 '9A2: Frequent non food'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S9A2Q0
	201 ' Cotton ' 
	202 ' Silk ' 
	203 ' Hand Loomed Cloth ' 
	204 ' Polyester Material ' 
	205 ' All Other Clothing Material (Natural fibre or otherwise) ' 
	206 ' Tailoring Charges ' 
	207 ' Suit / Safari Suit ' 
	208 ' Smock or Other Hand Woven Garment ' 
	209 ' Dress (ladies/girls) ' 
	210 '  Trousers  Slacks  Shorts  Blouse  Shirts  ' 
	211 ' Underwear (Incl.Vests and Underpants) ' 
	212 ' Other Readymade Clothes ' 
	213 ' Mens Shoes ' 
	214 ' Mens Slippers ' 
	215 ' Ladies Shoes ' 
	216 ' Ladies Slippers ' 
	217 ' Boys shoes ' 
	218 ' Girls shoes ' 
	219 ' Repair of footwear ' 
	222 ' Bed sheets  Bed Cover  Blanket  Curtains   ' 
	223 ' Mattress  Pillow & Cases  ' 
	278 'Water Charges '
	279 'Kerosene and other liquid fuel (incl. Palm Kernel Oil)  '
	280 'Gas for Cooking '
	281 'Charcoal '
	282 'Firewood and Other Solid fuel '
	283 'Repairs to Clothing '
	284 'Repairs to Footwear '
	285 'Repairs to Soft Furnishings '
	286 'Repairs to Furniture and Fittings '
	287 'Repairs to Appliances '
	288 'Soap and Washing Powder '
	289 'Insecticides  Disinfectants and Household Cleaners  '
	290 'Matches '
	291 'Toilet paper '
	292 'Light Globes / Bulbs '
	293 'Candles '
	294 'Other Non-durable goods '
	295 'Household services (Lawns Boy  Washman  etc.)  '
	296 'Cooks '
	297 'Baby Sitters / Day Care Attendants  Nannies   Cleaners  '
	298 'Gardeners '
	299 'Security Guards '
	300 'Washmen '
	301 'Plumbing & Repairs '
	302 'Furniture and Furnishing Hire '
	303 'Pain Killers (Aspirin.) '
	304 'Antibiotics '
	305 'Anti malaria medicines '
	306 'Other Medical and Pharmaceutical Products  '
	307 'Medical Services such as Doctor or Healer and other Medical Expenses '
	308 'Car '
	309 'Motorcycle '
	310 'Bicycle '
	311 'Boat '
	312 'Other Personal Transport Equipment '
	313 'Tyres  Tubes  Pants  '
	314 'Other Accessories '
	315 'Petrol '
	316 'Diesel '
	317 'Oil & Grease '
	318 'Chiffonier and Driver Services '
	319 'Other Equipment  including repairs & serving  '
	320 'Road a rail Transport '
	321 'Inland water Transport '
	322 'Air Transport '
	323 'Ocean Transport '
	324 'Other Transport '
	325 'Postal Charges (Including stamps and courier services) '
	326 'Telegrams  Telephones  Faxes  etc  '
	327 'School Fees and Related Charges '
	328 'School Books and Stationery '
	329 'School Transport '
	330 'Boarding Lodging at School '
	331 'Other Expenses on Education '
	332 'School Uniform '
	333 'TV  Video  Radio  Cassette Player'
	334 'Musical Instruments '
	335 'Camera  Video Camera and Other Durable Photographic Equipment   '
	336 'Typewriter  Binoculars  Sports Equipment  '
	337 'Other Accessories and Repairs '
	338 'Books and Magazines '
	339 'Newspapers '
	340 'Transistor Batteries / Films & Other Non-Durable Photo Items '
	341 'Other Non-durable Items '
	342 'Football Cinema  Video Tickets and Charges  '
	343 'Membership of Sports  Video Societies and Other Clubs  '
	344 'Stationery Supplies  Wring Pad  Pens  Pall Pens  Pencils  Ink etc.  '
	345 'Drawing Equipment and Accessories '
	346 'Other Items and Repairs '
	346 'Services of Barber  Beauty Shops  and Others  '	
	347 'Personal Care Services  '
	348 'Barber Beauty Saloon '
	349 'Other Personal Care services '
	350 'Stationery Supplies  Wring Pad  Pens  Ball Pens  Pencils  Ink etc.  '
	351 'Drawing Equipment and Accessories '
	352 'Other Items and Repairs '
	353 'Services of Barber  Beauty Shops  and Others  '
	354 'Personal Care Services  '
	355 'Barber Beauty Salon '
	356 'Other Personal Care services '
	357 'Goods for Personal Care (eg. Razor Blades  Cosmetics  Powder  Tooth Paste  etc.)  '
	358 'Writing and Drawing Equipment and Supplies  '
	359 'Expenditure in Restaurants and Hotels '
	360 'Financial Services (N.E.S = Not Elsewhere Specified) '
	361 'Jewellery & Watcher '
	362 'Other Personal Goods '
	363 'Package Tours '
	364 'Goods N.E.C '
	365 'Other Services (N.E.S) '
	999 'Tobacco'
/S9A2Q1 S9A2Q5
	1 'Yes'
	2 'No'.
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S9A2Q6
  /ORDER=  ANALYSIS .


*Need to recode product codes to conform with a reclassification scheme due to different codes for
*purchases, own conspumption and the pricing questionnaire.



SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9A2.sav'.





*Section 9B:Frequently purchased items

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9B.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S9BQ0 14-16 S9BQ1 17-17 S9BQ2 18-20 S9BQ3 21-27 S9BQ4 35-35 
  S9BQ5 36-38 S9BQ6 28-34 S9BRC 39-41.

*data dictionary names and lengths do not conform in Q4-Q6.  This is the reason for stating them out of order.

EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S9BQ0		'Product Code'
	/S9BQ1		'Did purchase 12 months?'
	/S9BQ2		'How many times (12 months)?'
	/S9BQ3		'How much spent?'
	/S9BQ4		'Did purchase 3 months?'
	/S9BQ5		'How many times (3 months)?'
	/S9BQ6		'How much spent?'
	

*add value labels.

val labels 
  /
  /rectype
	18 '9B-Food Purchases'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S9BQ0
	001 'Fresh Pepper '
	002 'Salt  '
	003 'Pepper (Dried) '
	004 'Spices and other condiments '
	005 'Other miscellaneous food '
	006 'Bitter Kola '
	007 'Kola Nut '
	099 'Cookry '
	100 'Bread and Buns '
	101 'Maize-Cob (fresh) '
	102 'Maize-Flour Dough '
	103 'Millet Grain '
	104 'Millet Flour '
	105 'Rice (Paddy Grain) Local '
	106 'Rice (Paddy Grain) Imported '
	107 'Guinea Corn '
	108 'Sorghum '
	109 'Bananas '
	110 'Cassava Roots '
	111 'Cassava Gari '
	112 'Plantain '
	113 'Sweet Potato '
	114 'Coco Yams '
	115 'Yams '
	116 'Other Grains and flours '
	117 'Cassava (Other Forms) '
	118 'Other Roots and Tubers '
	119 'Other starchy products '
	200 'Bacon '
	201 'Fresh Cow meat (no bone) '
	202 'Chicken '
	203 'Mutton '
	204 'Pork '
	205 'Meat Sausage '
	206 'Bush Fowl '
	207 'Guinea Fowl '
	208 'Other domestic poultry '
	209 'Fresh Cow Meat (Bone) '
	210 'Goat '
	211 'Pigs Feet '
	212 'Ham '
	213 'Other domestic meat '
	214 'Wild meat '
	300 'Dried Fish '
	301 'Smoked Fish '
	302 'Shell Fish '
	303 'Fried Fish '
	304 'Fresh Fish '
	305 'Canned Fish '
	400 'Eggs '
	401 'Milk '
	402 'Other Egg '
	403 'Milk Powder '
	404 'Baby Milk '
	405 'Tinned Milk (unsweetened) '
	406 'Other Milk Products '
	500 'Palm Oil '
	501 'Palm Kernel Oil '
	502 'Groundnut oil '
	503 'Coconut Oil '
	504 'Other nuts and seeds '
	505 'Margarine '
	506 'Other vegetable oil/fats '
	507 'Animal fats '
	508 'Palm Nuts '
	509 'Ground Nuts (roasted or raw) '
	510 'Coconuts '
	511 'Shea Butter '
	600 'Watermelon '
	601 'Paw paw '
	602 'Oranges Tangerine '
	603 'Mangoes '
	604 'Pineapples '
	605 'Other Fresh Fruit '
	606 'Canned fruit '
	700 'Bambara Beans '
	701 'Cowpeas (Small) '
	702 'Broad beans '
	703 'Other pulses or legumes '
	704 'Avocado pears '
	705 'Tomatoes '
	706 'Onions '
	707 'Carrots '
	708 'Okra '
	709 'Gardens eggs cucumbers '
	710 'Cabbage/Lettuce '
	711 'Spinach/Other Leafy Vegetables '
	712 'Other vegetables '
	713 'Cabbage '
	800 'Biscuits '
	801 'Honey '
	802 'Sugar '
	803 'Ice cream lollipop '
	804 'Jams '
	805 'Confectionary not frozen '
	900 'Fruit juices '
	901 'Coffee '
	902 'Chocolate '
	903 'Tea '
	904 'Softdrinks '
	905 'Local and imported beer '
	906 'Palm Wine '
	907 'Bamboo Wine '
	908 'Omole and local spirits '
	909 'Gin/Sassman '
	910 'Other alcoholic '
	911 'Other non-alcoholic '
	998 'Health care personal; hygiene '
	999 'Tobacco '
/S9BQ1 S9BQ5
	1 'Yes'
	2 'No'.
EXECUTE.

*recoding to a common food code to match for caloric evaluation.

COMPUTE S9BQ0 =  S9BRC.
EXECUTE .


*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S9BQ6
  /ORDER=  ANALYSIS .


*Need to recode product codes to conform with a reclassification scheme due to different codes for
*purchases, own conspumption and the pricing questionnaire.



SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9B.sav'.


*Scetion 9C.

DATA LIST FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\HouseExp_Sec9C.tmp' RECORDS=1
/region 3-3 
district 3-4 
chiefdom 5-6 
ea 7-8 
urbrur 9-9 
hhnum 10-12 
HHID 3-12
S9CQ0    14-16   
S9CQ1   17-17   
S9CQ2    18-18   
.
VARIABLE LABELS
 S9CQ0 "Product Code"
/S9CQ1_PURCHASE "Purchases"
/S9CQ2_SHORTAGES "Shortages"
.
VALUE LABELS
 rectype
	18 '9C-Availability'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
S9CQ0
   400 "Health/Personal"
   401 "Firewood"
   402 "Kerosene"
   403 "Rice"
   404 "Palm Oil"
   405 "Sugar"
   406 "Salt"
   407 "Cooking Gas"
   408 "Clothes/Shoes"
/S9CQ1
     1 "Yes, often"
     2 "Yes, one or two"
     3 "No"
     4 "Not Applicable"
/S9CQ2
     1 "Worse now"
     2 "The same"
     3 "Not so bad"
.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\HouseExp_Sec9C.sav'.

*Section 10A.

DATA LIST FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10A.tmp' RECORDS=1
/region 3-3 
district 3-4 
chiefdom 5-6 
ea 7-8 
urbrur 9-9 
hhnum 10-12 
HHID 3-12
EID 	14-14  
S10AQ2 	15-16  
S10AQ3 	17-18  
S10AQ4  	19-21  
S10AQ5Y	22-23  
S10AQ5M 	24-25  
S10AQ6 	26-27  
S10AQ7   	28-28  
S10AQ8   	29-30  
S10AQ9   	31-31  
S10AQ10   	32-34  
S10AQ11   	35-36  
S10AQ12A   	37-38  
S10AQ12B   	39-40  
S10AQ13   	41-42  
S10QA14  	43-44  
S10AQ15   	45-45  
S10AQ16   	46-46  
S10AQ17   	47-47  
S10AQ18   	48-49  
S10AQ19   	50-50  
S10AQ20   	51-51  
S10AQ21   	52-60  
S10AQ22   	61-69  
.

SORT CASES BY
  HHID (A) EID (A) .

VARIABLE LABELS
 EID "Enterprise ID"
/S10AQ2 "Person Responsible"
/S10AQ3 "Person Interviewed"
/S10AQ4 "Activity"
/S10AQ5Y "Years in operation"
/S10AQ5M "Months in operation"
/S10AQ6 "Months operating in the last 12 months"
/S10AQ7 "Whose is the income"
/S10AQ8 "%age of income to the household"
/S10AQ9 "Registered?"
/S10AQ10 "How many people worked in the enterprise"
/S10AQ11 "Of these, how many are from the household?"
/S10AQ12A "IDs of household 1 member associated"
/S10AQ12B "IDs of household 2 member associated"
/S10AQ13 "How many apprentices"
/S10QA14 "Number of hires
/S10AQ15 "Wage contracts issued?"
/S10AQ16 "Any workers receive paid sick leave?"
/S10AQ17 "What is the most difficult issue in establishing business?"
/S10AQ18 "Source of capital"
/S10AQ19 "Attempted to get credit?"
/S10AQ20 "Source of credit"
/S10AQ21 "Amount borrowd in the last 12 months"
/S10AQ22 "Amount"
.
VALUE LABELS
 /rectype
	18 '10A-Characteristics of nn farm enterprises'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10AQ4  
	111 'Agricultural and livestock production'
	112 'Agricultural services'
	113 'Hunting, trapping and game'
	121 'Forestry'
	122 'Logging'
	130 'Fishing'
	210 'Coal mining'
	220 'Crude petroleum and natural gas production'
	230 'Metal ore mining'
	290 'Other mining'
	311 'Food manufactures'
	313 'Beverage industries'
	314 'Tobacco manufacturers'
	321 'Manufacture of textiles'
	322 'Manufacture of wearing apparel, except footwear'
	323 'Manufacture of leather and products of leather, except footwear and wearing apparel'
	324 'Manufacture of footwear, except vulcanized or mould rubber or plastic footwear'
	331 'Manufacture of wood and cork products, except furniture'
	332 'Manufacture of furniture and fixtures except primarily of metal'
	341 'Manufacture of paper and paper products'
	342 'Printing, publishing and allied industries'
	351 'Manufacture of basic industrial chemicals, including fertilizers'
	352 'Manufacture of other chemical products'
	353 'Petroleum refineries'
	354 'Manufacture of miscellaneous products of petroleum and coal'
	355 'Manufacture of rubber products'
	356 'Manufacture of plastic products not elsewhere classified'
	361 'Manufacture of pottery, china and earthenware'
	362 'Manufacture of glass and glass products'
	369 'Manufacture of other non-metallic mineral products'
	371 'Iron and steel basic industries'
	372 'Non-ferrous metal basic industries'
	381 'Manufacture of fabricated metal products, except machinery and equipment'
	382 'Manufacture of machinery except electrical'
	383 'Manufacture of electrical machinery apparatus, appliances and supplies'
	384 'Manufacture of transport equipment'
	385 'Manufacture of professional and scientific equipment, measuring and controlling instruments not elsew'
	390 'Other manufacturing industries'
	410 'Electricity, gas and steam'
	420 'Water works and supply'
	500 'Construction'
	610 'Wholesale trade'
	620 'Retail Trade'
	631 'Restaurants, cafes, other eating and drinking places'
	632 'Hotels, rooming houses, camps and other lodging places'
	711 'Land transport'
	712 'Water transport'
	713 'Air transport'
	719 'Services allied to transport'
	720 'Communication'
	810 'Financial institutions'
	820 'Insurance'
	831 'Real estate'
	832 'Business services except machinery rental and leasing'
	833 'Machinery rental and leasing'
	910 'Public administration and defence'
	920 'Sanitary and similar services'
	931 'Education services'
	932 'Research and scientific institutes'
	933 'Medical, dental, other health and veterinary services'
	934 'Welfare institutions'
	935 'Business, professional and labour associations'
	939 'Other social and related community services'
	941 'Motion picture and other entertainment services'
	942 'Libraries, museums, botanical and zoological gardens, and cultural services not elsewhere classified'
	949 'Amusement and recreational services not elsewhere classified'
	951 'Repair services not elsewhere classified'
	952 'Laundries, laundry services, and cleaning and dyeing plants'
	953 'Domestic services'
	959 'Miscellaneous personal services'
	960 'International and other extra-territorial bodies'
/S10AQ7
     1 "Yes"
     2 "No"
/S10AQ9
     1 "Yes"
     2 "No"
/S10AQ15
     1 "Yes"
     2 "No"
/S10AQ16
     1 "Yes"
     2 "No"
/S10AQ17
     1 "No difficulty"
     2 "Capital/Credit"
     3 "Technical"
     4 "Gov't Regulation"
     5 "Other"
/S10AQ18
     1 "Household Saving"
     2 "Loans from Bank"
     3 "Remittances"
     4 "Proceeds_Farm"
     5 "Proceeds_Nonfarm"
     6 "Family Property"
     7 "NGO Support"
     8 "Association"
     9 "Church Assist."
    10 "Relative/Friend"
    96 "Other"
/S10AQ19
     1 "Yes_Successfully"
     2 "Yes_Unsuccessful"
     3 "No"
/S10AQ20
     1 "No Credit Used"
     2 "Bank"
     3 "Other Agencies"
     4 "Cooperative"
     5 "Money Lender"
     6 "Family/Friend"
     7 "Proceeds"
     8 "Other"
.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10A.sav'.

*First Enterprise: Part B Expenditures

DATA LIST FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10B_1.tmp' RECORDS=1
/region 3-3 
district 3-4 
chiefdom 5-6 
ea 7-8 
urbrur 9-9 
hhnum 10-12 
HHID 3-12
 S10BQ0   14-15  
 S10BQ2A   16-16  
 S10BQ3A   17-17  
 S10BQ4A   18-18  
 S10BQ5A   19-25  
 S10BQ6A  26-32 
 S10BQ7A   33-39  
 S10BQ8A   40-40  
 S10BQ9A   41-41  
 S10BQ10A   42-42  
 S10BQ11A   43-43  
 S10BQ12A   44-50  
 S10BQ13A   51-57  
 S10BQ14A   58-64  
 S10BQ15A   65-65  
.
VARIABLE LABELS
 S10BQ0 "Inpute code"
/S10BQ2A "Spent on item in the last 12 months?"
/S10BQ3A "Pay for item at least once a week?"
/S10BQ4A "Times purchases in last 12 months"
/S10BQ5A "Amount spent in 12 months"
/S10BQ6A "Amount spent in last 3 months"
/S10BQ7A "Amount spent in last 2 weeks"
/S10BQ8A "Was the item ever unavailable"
/S10BQ9A "(Last two weeks) Spent on item in the last 12 months?"
/S10BQ10A "(Last two weeks) Pay for item at least once a week?"
/S10BQ11A "(Last two weeks) Times purchases in last 12 months"
/S10BQ12A "(Last two weeks) Amount spent in 12 months"
/S10BQ13A "(Last two weeks) Amount spent in last 3 months"
/S10BQ14A "(Last two weeks) Amount spent in last 2 weeks"
/S10BQ15A "(Last two weeks) Was the item ever unavailable"
.
VALUE LABELS
 region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10BQ0
     1 "Hired Labour"
     2 "Raw Materials"
     3 "Spare Parts"
     4 "Article of resal"
     5 "Rental of Land"
     6 "Rent. of Machine"
     7 "Maintenance"
     8 "Rent. of Vehicle"
     9 "Fuel/Lubricant"
    10 "Other Transport"
    11 "Electricity"
    12 "Water"
    13 "Taxes"
    14 "Other Expenses"
/S10BQ2A
     1 "Yes"
     2 "No"
/S10BQ3A
     1 "Yes"
     2 "No"
/S10BQ4A
     1 "12 or Less"
     2 "More than 12"
/S10BQ8A
     1 "Yes, Often"
     2 "Yes, Not often"
     3 "No"
/S10BQ9A
     1 "Yes"
     2 "No"
/S10BQ10A
     1 "Yes"
     2 "No"
/S10BQ11A
     1 "12 or Less"
     2 "More than 12"
/S10BQ15A
     1 "Yes, Often"
     2 "Yes, Not often"
     3 "No"
.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10B_1.sav'.

*Second Enterprise Part B Expenditures

DATA LIST FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10B_2.tmp' RECORDS=1
/region 3-3 
district 3-4 
chiefdom 5-6 
ea 7-8 
urbrur 9-9 
hhnum 10-12 
HHID 3-12
 S10BQ0   14-15  
 S10BQ2B   16-16  
 S10BQ3B   17-17  
 S10BQ4B   18-18  
 S10BQ5B   19-25  
 S10BQ6B  26-32 
 S10BQ7B   33-39  
 S10BQ8B   40-40  
 S10BQ9B   41-41  
 S10BQ10B   42-42  
 S10BQ11B   43-43  
 S10BQ12B   44-50  
 S10BQ13B   51-57  
 S10BQ14B   58-64  
 S10BQ15B   65-65  
.
VARIABLE LABELS
 S10BQ0 "Inpute code"
/S10BQ2B "Spent on item in the last 12 months?"
/S10BQ3B "Pay for item at least once a week?"
/S10BQ4B "Times purchases in last 12 months"
/S10BQ5B"Amount spent in 12 months"
/S10BQ6B "Amount spent in last 3 months"
/S10BQ7B "Amount spent in last 2 weeks"
/S10BQ8B "Was the item ever unavailable"
/S10BQ9B "(Last two weeks) Spent on item in the last 12 months?"
/S10BQ10B "(Last two weeks) Pay for item at least once a week?"
/S10BQ11B "(Last two weeks) Times purchases in last 12 months"
/S10BQ12B "(Last two weeks) Amount spent in 12 months"
/S10BQ13B "(Last two weeks) Amount spent in last 3 months"
/S10BQ14B "(Last two weeks) Amount spent in last 2 weeks"
/S10BQ15B "(Last two weeks) Was the item ever unavailable"
.
VALUE LABELS
 /region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10BQ0
     1 "Hired Labour"
     2 "Raw Materials"
     3 "Spare Parts"
     4 "Article of resal"
     5 "Rental of Land"
     6 "Rent. of Machine"
     7 "Maintenance"
     8 "Rent. of Vehicle"
     9 "Fuel/Lubricant"
    10 "Other Transport"
    11 "Electricity"
    12 "Water"
    13 "Taxes"
    14 "Other Expenses"
/S10BQ2B
     1 "Yes"
     2 "No"
/S10BQ3B
     1 "Yes"
     2 "No"
/S10BQ4B
     1 "12 or Less"
     2 "More than 12"
/S10BQ8B
     1 "Yes, Often"
     2 "Yes, Not often"
     3 "No"
/S10BQ9B
     1 "Yes"
     2 "No"
/S10BQ10B
     1 "Yes"
     2 "No"
/S10BQ11B
     1 "12 or Less"
     2 "More than 12"
/S10BQ15B
     1 "Yes, Often"
     2 "Yes, Not often"
     3 "No"
.
EXECUTE.

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10B_2.sav'.

* Section: Enterprise_Sec10C

* Section: Enterprise_Sec10D

DATA LIST FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10C_1.tmp' RECORDS=1
/region 3-3 
district 3-4 
chiefdom 5-6 
ea 7-8 
urbrur 9-9 
hhnum 10-12 
HHID 3-12
S10C1Q0  14-14  
S10C1Q1A   15-15  
S10C1Q1B  16-16  
S10C1Q1C  17-17 
S10C1Q2A   18-26  
S10C1Q2B   27-35  
S10C1Q2C   36-44  
S10C1Q3A  45-46 
S10C1Q3B   47-48  
S10C1Q3C   49-50  
S10C1Q4A   51-59  
S10C1Q4B   60-68  
S10C1Q4C   69-77  
S10C1Q5   78-78  
S10C1Q6   79-87  
S10C1Q7   88-88  
S10C1Q8  89-97  
S10C1Q9  98-98  
.
VARIABLE LABELS
S10C1Q0 "Asset Code"
/S10C1Q1A "Own Item 1"
/S10C1Q1B "Own Item 2"
/S10C1Q1C "Own Item 3"
/S10C1Q2A "Sell value of item 1"
/S10C1Q2B "Sell value of item 2"
/S10C1Q2C "Sell value of item 3"
/S10C1Q3A "Age of item 1"
/S10C1Q3B "Age of item 2"
/S10C1Q3C "Age of item 3"
/S10C1Q4A "Purchase price of item 1"
/S10C1Q4B "Purchase price of item 2"
/S10C1Q4C "Purchase price of item 3"
/S10C1Q5 "Obtained in the last 12 months?"
/S10C1Q6 "Amount paid for the item in the last 12 months?"
/S10C1Q7 "Did the enterprise sell any assets?"
/S10C1Q8 "Value of assets sold"
/S10C1Q9 "Reason for sale of assets"
.
VALUE LABELS
 region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10C1Q0
     1 "Buildings"
     2 "Lands"
     3 "Machinery/Tools"
     4 "Bicycles"
     5 "Lorries"
     6 "Cars"
     7 "Boats"
     8 "Other Vehicles"
     9 "Other"
/S10C1Q1A
     1 "Yes"
     2 "No"
/S10C1Q1B
     1 "Yes"
     2 "No"
/S10C1Q1C
     1 "Yes"
     2 "No"
/S10C1Q5
     1 "Yes"
     2 "No"
/S10C1Q7
     1 "Yes"
     2 "No"
/S10C1Q9
     1 "Business Slump"
     2 "Debt Repayment"
     3 "Tax too high"
     4 "Moving Business"
     5 "Upgrading Assets"
     6 "Other"
.
EXECUTE.

FREQUENCIES
  VARIABLES=region to S10C1Q9
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10C_1.sav'.

* Section: Enterprise_Sec10D:Enterprise 2

DATA LIST FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10C_2.tmp' RECORDS=1
/region 3-3 
district 3-4 
chiefdom 5-6 
ea 7-8 
urbrur 9-9 
hhnum 10-12 
HHID 3-12
S10C2Q0  14-14  
S10C2Q1A   15-15  
S10C2Q1B  16-16  
S10C2Q1C  17-17 
S10C2Q2A   18-26  
S10C2Q2B   27-35  
S10C2Q2C   36-44  
S10C2Q3A  45-46 
S10C2Q3B   47-48  
S10C2Q3C   49-50  
S10C2Q4A   51-59  
S10C2Q4B   60-68  
S10C2Q4C   69-77  
S10C2Q5   78-78  
S10C2Q6   79-87  
S10C2Q7   88-88  
S10C2Q8  89-97  
S10C2Q9  98-98  
.
VARIABLE LABELS
S10C2Q0 "Asset Code"
/S10C2Q1A "Own Item 1"
/S10C2Q1B "Own Item 2"
/S10C2Q1C "Own Item 3"
/S10C2Q2A "Sell value of item 1"
/S10C2Q2B "Sell value of item 2"
/S10C2Q2C "Sell value of item 3"
/S10C2Q3A "Age of item 1"
/S10C2Q3B "Age of item 2"
/S10C2Q3C "Age of item 3"
/S10C2Q4A "Purchase price of item 1"
/S10C2Q4B "Purchase price of item 2"
/S10C2Q4C "Purchase price of item 3"
/S10C2Q5 "Obtained in the last 12 months?"
/S10C2Q6 "Amount paid for the item in the last 12 months?"
/S10C2Q7 "Did the enterprise sell any assets?"
/S10C2Q8 "Value of assets sold"
/S10C2Q9 "Reason for sale of assets"
.
VALUE LABELS
 region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10C2Q0
     1 "Buildings"
     2 "Lands"
     3 "Machinery/Tools"
     4 "Bicycles"
     5 "Lorries"
     6 "Cars"
     7 "Boats"
     8 "Other Vehicles"
     9 "Other"
/S10C2Q1A
     1 "Yes"
     2 "No"
/S10C2Q1B
     1 "Yes"
     2 "No"
/S10C2Q1C
     1 "Yes"
     2 "No"
/S10C2Q5
     1 "Yes"
     2 "No"
/S10C2Q7
     1 "Yes"
     2 "No"
/S10C2Q9
     1 "Business Slump"
     2 "Debt Repayment"
     3 "Tax too high"
     4 "Moving Business"
     5 "Upgrading Assets"
     6 "Other"
.
EXECUTE.

FREQUENCIES
  VARIABLES=region to S10C2Q9
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10C_2.sav'.






* Section: Enterprise_Sec10D

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10D.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 EID 14-14 S10DQ1 15-23 S10DQ2 24-24 S10DQ3 25-33 S10DQ4 34-34 S10DQ5 35-43 
  S10DQ6 44-52 S10DQ7 53-53 S10DQ8 54-62 S10DQ9 63-63 S10DQ10 64-72 S10DQ11 73-73 S10DQ12 74-82 S10DQ13 83-83.

*sort cases by the key variables.

SORT CASES BY
  HHID (A) EID (A) .


*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/EID	 	'Enterprise Number'
	/S10DQ1 	'Money received in last 2 weeks from sales?'
	/S10DQ2 	'Goods and services received in the last 2 weeks?'
	/S10DQ3 	'Estimated amount of the payments in goods and services'
	/S10DQ4 	'Any goods and services produced consumed by the household instead of sold?'
	/S10DQ5 	'Value of goods and services consumed by household in the last two weeks'
	/S10DQ6 	'How much usually received by this enterprise in a 2 week period?'
	/S10DQ7 	'Does the enterprise usually receive payment in the form of goods and services?'
	/S10DQ8 	'Usual value of goods and services consumed by the household in 2 weeks?'
	/S10DQ9 	'Are some of the products consumed by the household instead of sold?'
	/S10DQ10 	'What is the value of products consumed by the household over a two week period?'
	/S10DQ11 	'Rent out any building, equipment or land?'
	/S10DQ12 	'How much received from rental?'
	/S10DQ13	'How do gross receipts of the enterprise compare with las year?'
	
*add value labels.

val labels 
/
/rectype
	26 '10D-Enterprise Revenue'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10DQ2 S10DQ4 S10DQ7 S10DQ9 S10DQ11
	1 'Yes'
	2 'No'
/S10DQ13
	1 'Higher'
	2 'Lower'
	3 'No difference'
	4 'Not applicable'.
EXECUTE. 

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S10DQ13
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10D.sav'.

* Section: Enterprise_Sec10E
 
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Enterprise_Sec10E.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 EID 14-14 S10E1A  15-23 S10E1T 24-24 S10E2A 25-33 S10E2T 34-34  
S10E3 35-35 S10E4A 36-44  S10E4T 45-45  S10E5 46-46 S10E6A 47-55 S10E6T 56-56 S10E7 57-57 S10E8A 58-66 S10E8T 67-67 S10E9 68-68 S10E10 69-76 .

*sort cases by the key variables.

SORT CASES BY
  HHID (A) EID (A) .

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/EID		'Enterprise Number'
	/S10E1A    	'How much money goes to household?'
	/S10E1T  	'Time unit'
	/S10E2A  	'How much money for personal use'
	/S10E2T  	'TIme Unit'
	/S10E3 		'Does some go to another household?'
	/S10E4A  	'How much to another household'
	/S10E4T  	'Time unit'
	/S10E5  	'Does some go for enterprise savings?'
	/S10E6A  	'How much for enterprise savings?'
	/S10E6T 	'Time unit'
	/S10E7  	'For any other purpose?'
	/S10E8A  	'How much goes for other purposes?'
	/S10E8T 	'Time unit'
	/S10E9		'Are there stocks of unsold items?' 
	/S10E10 	'Value of stocks'
	
*add value labels.

val labels 
/
/rectype
	26 '10E-Net Income'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S10E1T  S10E2T  S10E4T  S10E6T S10E8T 
	1 'Daily'
	2 'Weekly'
	3 '2 weeks'
	4 'Monthly'
	5 'Quarterly'
	6 'Yearly'
/S10E3 S10E5 S10E7 S10E9 
	1 'Yes'
	2 'No'.
EXECUTE.

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S10E10
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Enterprise_Sec10E.sav'.


*-----------------------------
*Section 11A: Income
*-------------------------------

 

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Income_Sec11A.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S11AQID 14-15 COLA 16-17 S11AQ1 18-25 S11AQ2 26-33 S11AQ3 34-41 
  S11AQ4 42-49 S11AQ5 50-57 S11AQ6 58-65  S11AQ7 66-73 S11AQ8 74-81 S11AQ9 82-90 S11AQ10 91-98 S11AQ11 99-106 S11AQ12 107-114 S11AQ13 115-122
  S11AQ14 123-130 S11AQ15 131-138 S11AQ16 139-147.
EXECUTE.


*sort cases by the key variables.

SORT CASES BY
  HHID (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S11AQID 	'Line Number'
	/COLA 		'Column A'
	/S11AQ1 	'Salaries and Wages'
	/S11AQ2 	'Other receipts from employers'
	/S11AQ3 	'Net income from self-employment'
	/S11AQ4 	'Business Profits'
	/S11AQ5	'Rent, Interest and Dividends'
	/S11AQ6  	'Royalties and Comissions'
	/S11AQ7 	'Periodic payments'
	/S11AQ8 	'Social Security'
	/S11AQ9 	'Sub total 1-8'
	/S11AQ10 	'Wage payments in-kind'
	/S11AQ11 	'Goods and services transferred'
	/S11AQ12 	'Home produced consumption'
	/S11AQ13 	'Discounts received'
	/S11AQ14 	'Net rental value of owner occupied house'
	/S11AQ15 	'Gross rental value of rent-free house'
	/S11AQ16 	'Subtotal (10-17)'
	
*add value labels.

val labels 
/
/rectype
	28 '11A-Average Income'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/COLA 
	1 'Less than 50,000 Leones'
	2 '50,000 to 99,999 Leones'
	3 '100,000 to 149,999 Leones'
	4 '150,000 to 199,999 Leones'
	5 '200,000 to 249,999 Leones'
	6 '250,000 to 299,999 Leones'
	7 '300,000 to 399,999 Leones'
	8 '400,000 to 499,999 Leones'
	9 '500,000 to 599.999 Leones'
	10 '600,000 to 699,999 Leones'
	11 '700,000 to 899,999 Leones'
	12 '900,000 to 1,099,999 Leones'
	13 '1,100,000 to 1,999,999 Leones'
	14 '2,000,000 Leones and above'.


FREQUENCIES
  VARIABLES=rectype to S11AQ16 
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Income_Sec11A.sav'.

*-----------------------------.
*Section 11A:Transfers OUT.
*------------------------------.

 

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Income_Sec11BA.tmp'FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 SQ11BAO 14-14 SQ11BAID 15-16 SQ11BA4 17-18 SQ11BA5 19-19 SQ11BA6 20-20
  SQ11BA7 21-21 SQ11BA8 22-29 SQ11BA9 30-37 SQ11BA10 38-45 SQ11BA11 46-47 SQ11BA12 48-48.
EXECUTE.


*sort cases by the key variables.

SORT CASES BY
  HHID (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/SQ11BAO 	'Order'
	/SQ11BAID 	'ID of sender'
	/SQ11BA4 	'Relationship of recipient'
	/SQ11BA5  	'Sex of recipient'
	/SQ11BA6 	'Regular remittances?'
	/SQ11BA7  	'Will they be made in the future?'
	/SQ11BA8  	'Total cash transferred'
	/SQ11BA9  	'Food value transferred'
	/SQ11BA10  	'Other value transferred'
	/SQ11BA11 	'Recipient residence'
	/SQ11BA12 	'How does recipient use money?'
	
*add value labels.

val labels 
/
/rectype
	30 '11BA-Transfers OUT'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/SQ11BA4 
	1 'Spouse'
	2 'Child'
	3 'Son/Daugh In_law'
	4 'Grandchild'
	5 'Parent'
	6 'Parent In_law'
	7 'Sibling'
	8 'Neice/Nephew'
	9 'Friend'
	10 'Other Relative'
	11 'Uncle or Aunt'
	12 'Non_Relative'
	13 'Other'
/SQ11BA5  
	1 'Male'
	2 'Female'
/SQ11BA6 
	1 'Yes, Weekly'
	2 'Yes, Monthly'
	3 'Yes, Quarterly'
	4 'Yes, Annually'
	5 'No'
	6 'Other'
/SQ11BA7
	1 'Yes'
	2 'No'  
/SQ11BA11 
	1 'This village'
	2 'Freetown'
	3 'Bo'
	4 'Kenema'
	5 'Kono'
	6 'Makeni'
	7 'Other Urban'
	8 'Rural'
	9 'Abroad (Africa)'
	10 'Abroad (Other)'
/SQ11BA12 
	1 'Consumption'
	2 'Schooling'
	3 'Invest Non_farm'
	4 'Invest in Farm'
	5 'Build House'
	6 'Other'
	7 "Don't Know".

FREQUENCIES
  VARIABLES=rectype to SQ11BA12 
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\IncomeTransOUT_Sec11BA.sav'.

*-----------------------------.
*Section 11B:Transfers IN.
*-------------------------------.

 

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Income_Sec11BB.tmp'FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 SQ11BBO 14-14 SQ11BBID 15-16 SQ11BB4 17-18 SQ11BB5 19-19 SQ11BB6 20-20
  SQ11BB7 21-21 SQ11BB8 22-29 SQ11BB9 30-37 SQ11BB10 38-45 SQ11BB11 46-47 SQ11BB12 48-48.
EXECUTE.


*sort cases by the key variables.


*sort cases by the key variables.

SORT CASES BY
  HHID (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/SQ11BBO 	'Order'
	/SQ11BBID 	'ID of recipient
	/SQ11BB4 	'Relationship to sender'
	/SQ11BB5  	'Sex of sender'
	/SQ11BB6 	'Regular remittances?'
	/SQ11BB7  	'Will they be made in the future?'
	/SQ11BB8  	'Total cash transferred'
	/SQ11BB9  	'Food value transferred'
	/SQ11BB10  	'Other value transferred'
	/SQ11BB11 	'Sender residence'
	/SQ11BB12 	'How does recipient use money?'
	
*add value labels.

val labels 
/
/rectype
	30 '11BB-Transfers IN'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/SQ11BB4 
	1 'Spouse'
	2 'Child'
	3 'Son/Daugh In_law'
	4 'Grandchild'
	5 'Parent'
	6 'Parent In_law'
	7 'Sibling'
	8 'Neice/Nephew'
	9 'Friend'
	10 'Other Relative'
	11 'Uncle or Aunt'
	12 'Non_Relative'
	13 'Other'
/SQ11BB5  
	1 'Male'
	2 'Female'
/SQ11BB6 
	1 'Yes, Weekly'
	2 'Yes, Monthly'
	3 'Yes, Quarterly'
	4 'Yes, Annually'
	5 'No'
	6 'Other'
/SQ11BB7
	1 'Yes'
	2 'No'  
/SQ11BB11 
	1 'This village'
	2 'Freetown'
	3 'Bo'
	4 'Kenema'
	5 'Kono'
	6 'Makeni'
	7 'Other Urban'
	8 'Rural'
	9 'Abroad (Africa)'
	10 'Abroad (Other)'
/SQ11BB12 
	1 'Consumption'
	2 'Schooling'
	3 'Invest Non_farm'
	4 'Invest in Farm'
	5 'Build House'
	6 'Other'
	7 "Don't Know".

FREQUENCIES
  VARIABLES=rectype to SQ11BB12
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\IncomeTransIN_Sec11BB.sav'.

*------------------------------------------------.
*Section: Misc_Sec11C.tmp'
*------------------------------------------------.
SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Misc_Sec11C.tmp'FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S11CQ1 14-22 S11CQ2 23-31 S11CQ3 32-40 S11CQ4 41-49 S11CQ5 50-58
  S11CQ6 59-67 S11CQ7 68-76 S11CQ8 77-85 S11CQ9 86-94 S11CQ10 95-103 S11CQ11 104-112 S11CQ12 113-121 S11CQ13 122-130 S11CQ14 131-139
  S11CQ15 140-148 S11CQ16 149-157 S11CQ17 158-166 S11CQ18 167-175 S11CQ19 176-184 S11CQ20 185-193 S11CQ21 194-202 S11CQ22 203-211 
  S11CQ23 212-220 S11CQ24 221-229  S11DQ1 230-238 S11DQ2 239-247 S11DQ3 248-256 S11DQ4 257-265 S11DQ5 266-274 .
EXECUTE.


*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S11CQ1	'National Social and Insurance Trust'
	/S11CQ2	'Social subsidies to war vistims and the disabled'
	/S11CQ3	'Funds related to Government poverty alleviation'
	/S11CQ4	'Interest on treasury bills and bearer bonds'
	/S11CQ5	'Interest on development stocks or loans'
	/S11CQ6	'Insurance'
	/S11CQ7	'Lottery winnings'
	/S11CQ8	'Income form leas of buildings, land and other assets'
	/S11CQ9	'Income from sale of buildings and equipment'
	/S11CQ10	'Sale of vehicles'
	/S11CQ11	'Sale of durable goods'
	/S11CQ12	'Other income'
	/S11CQ13	'Gifts and presents'
	/S11CQ14	'Sale of durable goods'
	/S11CQ15	'Sale of silver and diamond'
	/S11CQ16	'Sale of vehicles'
	/S11CQ17	'income from lease of durable goods'
	/S11CQ18	'Weddings and dowery'
	/S11CQ19	'Funerals'
	/S11CQ20	'Osusu'
	/S11CQ21	'Sale of gold and jewelry'
	/S11CQ22	'Retrenchment benefits'
	/S11CQ23	'Retirement benefits'
	/S11CQ24	'Other income'
	/S11DQ1	'Property Taxes'
	/S11DQ2	'Self-help contributions' 
	/S11DQ3	'Ceremonial expenses'
	/S11DQ4	'Gifts and presents'
	/S11DQ5	'Other items'
	
val labels 
/
/rectype
	33 '11C-Misc'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'.
FREQUENCIES
  VARIABLES=rectype to S11DQ5
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Misc_Sec11C.sav'.


*Section: Credit_Sec12A: Credits

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Credit_Sec12A.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S12AQ3 14-14 S12AQ4 15-16 S12AQ5 17-18 S12AQ6 19-28 
  S12AQ7 29-29 S12AQ8 30-30 S12AQ9 31-40 S12AQ10 41-41 S12AQ11A 42-42 S12AQ11B 43-44 S12AQ12 45-45 .
EXECUTE.



*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S12AQ3 	'Loan number'
	/S12AQ4 	'Member obtaining the loan'
	/S12AQ5 	'Source of the loan'
	/S12AQ6 	'Total amount of the original loan'
	/S12AQ7 	'Purpose the loan was obtained'
	/S12AQ8 	'Guarantee required by the lender'
	/S12AQ9 	'How much of the loan has bee repaid in the last 12 months?'
	/S12AQ10	'Has any member been refused in the las 12 months?' 	
	/S12AQ11A 	Loan number refused'
	/S12AQ11B 	'Member refused'
	/S12AQ12 	'Reason refused'
	
*add value labels.

val labels 
/
/rectype
	35 '12A-Credit'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S12AQ5 
	1 'State Bank (BSL)'
	2 'Private Bank'
	3 'Cooperative'
	4 'Govt Agency'
	5 'NGOs'
	6 'Other Formal'
	7 'Money Lender'
	8 'Trader'
	9 'Farmer'
	10 'Relative/Friend'
	11 'Other Informal'	
/S12AQ7 
	1 'Agric Land/Equip'
	2 'Agric Inputs'
	3 'Business Expans'
	4 'Housing'
	5 'Education'
	6 'Health'
	7 'Wedding/Funerals'
	8 'Consumer Goods'
	9 'Other'
/S12AQ8 
	1 'Land'
	2 'Cattle'
	3 'Housing'
	4 'Other'
	5 'None'
/S12AQ12 	
	1 'Insuffic Income'
	2 'Insuffic Collateral'
	3 'Debt Problems'
	4 'Purpose of Loan'
	5 'Other'.
EXECUTE. 

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S12AQ12
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Credits_Sec12A.sav'.



*Section: Credit_Sec12B: assets and Durable Goods

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Credit_Sec12B.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S12BQ0 14-16 S12BQ1A 17-17 S12BQ1B 18-18 S12BQ2A 19-20 
  S12BQ2B 21-22 S12BQ3A 23-32 S12BQ3B 33-42 S12BQ4A 43-52 S12BQ4B 53-62 .
EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S12BQ0 	'Product Code'
	/S12BQ1A 	'Does the household own? (1)'
	/S12BQ1B 	'Does the household own? (2)'
	/S12BQ2A 	'How long ago obtained (1)?'
	/S12BQ2B 	'How long ago obtained (2)?'
	/S12BQ3A 	'Purchase price (1)'
	/S12BQ3B 	'Purchase price (2)'
	/S12BQ4B 	'Value today (1)'
	/S12BQ4B  	'Value today (2)'
	
*add value labels.

val labels 
/
/rectype
	36 '12B-Durable goods'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'
/S12BQ0
	301 'Furniture'
	302 'Sewing Machine'
	303 'Stove'
	304 'Refrigerator'
	305 'Air Conditioner'
	306 'Fan'
	307 'Radio'
	308 'Radio Cassette'
	309 'Record Player'
	310 '3_In_One Radio'
	311 'Video Equipment'
	312 'Washing Machine'
	313 'T.V.'
	314 'Camera'
	315 'Iron(Electric)'
	316 'Bicycle'
	317 'Motor Cycle'
	318 'Car'
	319 'House'
	320 'Land/Plot'
	321 'Shares'
	322 'Boat'
	323 'Canoes'
	324 'Out Board'
/S12BQ1A S12BQ1B
	1 'Yes'
	2 'No'.
EXECUTE. 

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S12BQ4B
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Credits_Sec12B.sav'.


*Section: Credit_Sec12C: Savings

SET
   BLANKS=SYSMIS
  UNDEFINED=WARN.

DATA LIST
  FILE='C:\Sierra Leone_Household Survey_2003\Raw_Data\Temp\Credit_Sec12C.tmp' FIXED RECORDS=1 TABLE /1 rectype 1-2 
  region 3-3 district 3-4 chiefdom 5-6 ea 7-8 urbrur 9-9 hhnum 10-12 HHID 3-12 S12CQ2 14-14 S12CQ3 15-16 S12CQ4 17-26 S12CQ5 27-36 S12CQ6 37-46. 
EXECUTE.

*sort cases by the key variables.

SORT CASES BY
  region (A) district (A) chiefdom (A).

*add variable labels - these are in English so that it will be easier for me to clean.

var lab
	rectype 		'Record type'
	/region   	'Region'
	/district	 	'District'
	/chiefdom	'Chiefdom'
	/ea		'Enumerator Area'
	/urbrur		'Urban/Rural'
	/hhnum		'Household number'
	/HHID		'Household ID (Key)'
	/S12CQ2 	'Savings item number'
	/S12CQ3 	'Name the account is in?'
	/S12CQ4 	'Current value of savings' 
	/S12CQ5 	'Amount added to the savings in last 12 months?'
	/S12CQ6	'Amount withdrawn in the last 12 months?'
*add value labels.

val labels 
/
/rectype
	38 '12-C Savings'
/region
	0 'Southern'
	1 'Eastern'
	2 'Northen'
	3 'Western'
/district
	01 'Bo'
	02 'Bonthe'
	03 'Moyamba'
	04 'Pujehun'
	11 'Kailahun'
	12 'Kenema'
	13 'Kono'
	21 'Bombali'
	22 'Kambia'
	23 'Koinadugu'
	24 'Porto Loko'
	25 'Tonkolili'
	31 'Freetown'
	32 'Western Other'.
	
EXECUTE. 

*frequecies of all variables to look for possible mistakes in column
 specification or misalignment of data in the original .txt file.

FREQUENCIES
  VARIABLES=rectype to S12CQ6
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\Sierra Leone_Household Survey_2003\Sectional\Credits_Sec12C.sav'.
